/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import gnu.trove.THashSet;

import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;
import javax.persistence.Transient;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class Agency.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Agency extends BaseEntity {

    /**
     * The Enum LanguageContentKey.
     */
    public enum LanguageContentKey {
        
        /** The ABSENCE. */
		 ABSENCE, 
 
 /** The ABSENC e_ percentage. */
 ABSENCE_PERCENTAGE, 
 
 /** The ABSENT. */
  ABSENT, 
 
 /** The ABSEN t_ occassions. */
 ABSENT_OCCASSIONS, 
 
 /** The ACTIV e_ b y_ default. */
 ACTIVE_BY_DEFAULT, 
 
 /** The AD d_ language. */
 ADD_LANGUAGE, 
 
 /** The ADMI n_ menu. */
 ADMIN_MENU, 
 
 /** The AGREEMENTS. */
 AGREEMENTS, 
  
 /** The AGREMEN t_ percentage. */
 AGREMENT_PERCENTAGE, 
 
 /** The ALLOWANCES. */
 ALLOWANCES, 
 
 /** The BALLOT. */
 BALLOT, 
 
 /** The BALLOTS. */
 BALLOTS, 
 
 /** The BUTTO n_ cancel. */
 BUTTON_CANCEL, 
 
 /** The BUTTO n_ delete. */
 BUTTON_DELETE, 
 
 /** The BUTTO n_ login. */
 BUTTON_LOGIN, 
 
 /** The BUTTO n_ ne w_ portal. */
 BUTTON_NEW_PORTAL, 
 
 /** The BUTTO n_ ok. */
 BUTTON_OK, 
 
 /** The CATEGORY. */
 CATEGORY, 
 
 /** The CHARTS. */
 CHARTS, 
 
 /** The CITIZE n_ operation. */
 CITIZEN_OPERATION, 
 
 /** The COMMITE e_ report. */
 COMMITEE_REPORT, 
 
 /** The CONFIGUR e_ agency. */
 CONFIGURE_AGENCY, 
 
 /** The CONFIGUR e_ language. */
 CONFIGURE_LANGUAGE, 
 
 /** The CONFIGUR e_ portal. */
 CONFIGURE_PORTAL, 
 
 /** The CURREN t_ action. */
 CURRENT_ACTION, 
 
 /** The DECISIO n_ date. */
 DECISION_DATE, 
 
 /** The DONAT e_ t o_ project. */
 DONATE_TO_PROJECT, 
 
 /** The ELECTORA l_ area. */
 ELECTORAL_AREA, 
 
 /** The ERRO r_ message. */
 ERROR_MESSAGE, 
 
 /** The FIRS t_ vote. */
 FIRST_VOTE, 
 
 /** The FORUM. */
 FORUM, 
 
 /** The FRIEND s_ an d_ enemies. */
 FRIENDS_AND_ENEMIES, 
 
 /** The GRADING. */
 GRADING, 
 
 /** The HOM e_ page. */
 HOME_PAGE, 
 
 /** The HOUSES. */
 HOUSES, 
 
 /** The INCOM e_ activity. */
 INCOME_ACTIVITY, 
 
 /** The INFORMATION. */
 INFORMATION, 
 
 /** The INSID e_ party. */
 INSIDE_PARTY, 
 
 /** The LANGUAG e_ conten t_ key. */
 LANGUAGE_CONTENT_KEY, 
 
 /** The LANGUAG e_ conten t_ value. */
 LANGUAGE_CONTENT_VALUE, 
 
 /** The LANGUAG e_ shortcode. */
 LANGUAGE_SHORTCODE, 
 
 /** The LAS t_ te n_ decide d_ commite e_ reports. */
 LAST_TEN_DECIDED_COMMITEE_REPORTS, 
 
 /** The LAS t_ te n_ decide d_ commite e_ report s_ description. */
 LAST_TEN_DECIDED_COMMITEE_REPORTS_DESCRIPTION, 
 
 /** The LAS t_ vote. */
 LAST_VOTE, 
 
 /** The LOGIN. */
 LOGIN, 
 
 /** The LOGOUT. */
 LOGOUT, 
 
 /** The LOSE r_ percent. */
 LOSER_PERCENT, 
 
 /** The LOSERS. */
 LOSERS, 
 
 /** The LOST. */
 LOST, 
 
 /** The LOYAL. */
 LOYAL, 
 
 /** The LOYA l_ occassions. */
 LOYAL_OCCASSIONS, 
 
 /** The LOYA l_ percent. */
 LOYAL_PERCENT, 
 
 /** The LOYA l_ percentag e_ b y_ party. */
 LOYAL_PERCENTAGE_BY_PARTY, 
 
 /** The LOYALTIES. */
 LOYALTIES, 
 
 /** The MATCHE s_ url. */
 MATCHES_URL, 
 
 /** The NAME. */
 NAME, 
 
 /** The NEUTRAL. */
 NEUTRAL, 
 
 /** The NO. */
 NO, 
 
 /** The N o_ registe r_ information. */
 NO_REGISTER_INFORMATION, 
 
 /** The N o_ registe r_ informatio n_ msg. */
 NO_REGISTER_INFORMATION_MSG, 
 
 /** The NOTHIN g_ declared. */
 NOTHING_DECLARED, 
 
 /** The OPINIONS. */
 OPINIONS, 
 
 /** The OTHE r_ loyalties. */
 OTHER_LOYALTIES, 
 
 /** The OUTCOME. */
 OUTCOME, 
 
 /** The PARLIAMEN t_ member s_ absence. */
 PARLIAMENT_MEMBERS_ABSENCE, 
 
 /** The PARLIAMEN t_ member s_ absenc e_ description. */
 PARLIAMENT_MEMBERS_ABSENCE_DESCRIPTION, 
 
 /** The PARLIAMEN t_ member s_ losers. */
 PARLIAMENT_MEMBERS_LOSERS, 
 
 /** The PARLIAMEN t_ member s_ loser s_ description. */
 PARLIAMENT_MEMBERS_LOSERS_DESCRIPTION, 
 
 /** The PARLIAMEN t_ member s_ loyal. */
 PARLIAMENT_MEMBERS_LOYAL, 
 
 /** The PARLIAMEN t_ member s_ loya l_ description. */
 PARLIAMENT_MEMBERS_LOYAL_DESCRIPTION, 
 
 /** The PARLIAMEN t_ member s_ presence. */
 PARLIAMENT_MEMBERS_PRESENCE, 
 
 /** The PARLIAMEN t_ member s_ presenc e_ description. */
 PARLIAMENT_MEMBERS_PRESENCE_DESCRIPTION, 
 
 /** The PARLIAMEN t_ member s_ rebels. */
 PARLIAMENT_MEMBERS_REBELS, 
 
 /** The PARLIAMEN t_ member s_ rebel s_ description. */
 PARLIAMENT_MEMBERS_REBELS_DESCRIPTION, 
 
 /** The PARLIAMEN t_ member s_ winners. */
 PARLIAMENT_MEMBERS_WINNERS, 
 
 /** The PARLIAMEN t_ member s_ winner s_ description. */
 PARLIAMENT_MEMBERS_WINNERS_DESCRIPTION, 
 
 /** The PARTY. */
 PARTY, 
 
 /** The PART y_ loyal. */
 PARTY_LOYAL, 
 
 /** The PART y_ rebel. */
 PARTY_REBEL, 
 
 /** The PART y_ status. */
 PARTY_STATUS, 
 
 /** The PASSWORD. */
 PASSWORD, 
 
 /** The PE r_ party. */
 PER_PARTY, 
 
 /** The POLITICA l_ part y_ behavior. */
 POLITICAL_PARTY_BEHAVIOR, 
 
 /** The PORTALS. */
 PORTALS, 
 
 /** The PRESENCE. */
 PRESENCE, 
 
 /** The PRESENC e_ occassions. */
 PRESENCE_OCCASSIONS, 
 
 /** The PRESENC e_ percentage. */
 PRESENCE_PERCENTAGE, 
 
 /** The PRESEN t_ percentag e_ b y_ party. */
 PRESENT_PERCENTAGE_BY_PARTY, 
 
 /** The PROFFESSIONA l_ behavior. */
 PROFFESSIONAL_BEHAVIOR, 
 
 /** The PROJEC t_ information. */
 PROJECT_INFORMATION, 
 
 /** The PUBLI c_ roles. */
 PUBLIC_ROLES, 
 
 /** The RANK. */
 RANK, 
 
 /** The REBE l_ occassions. */
 REBEL_OCCASSIONS, 
 
 /** The REBE l_ percentage. */
 REBEL_PERCENTAGE, 
 
 /** The REBELS. */
 REBELS, 
 
 /** The REGISTERE d_ votes. */
 REGISTERED_VOTES, 
 
 /** The RIKSDA g_ information. */
 RIKSDAG_INFORMATION, 
 
 /** The ROLES. */
 ROLES, 
 
 /** The SEARCH. */
 SEARCH, 
 
 /** The SEARC h_ description. */
 SEARCH_DESCRIPTION, 
 
 /** The SEARC h_ result. */
 SEARCH_RESULT, 
 
 /** The SHOR t_ comment. */
 SHORT_COMMENT, 
 
 /** The SHO w_ recen t_ actions. */
 SHOW_RECENT_ACTIONS, 
 
 /** The SHO w_ respons e_ time. */
 SHOW_RESPONSE_TIME, 
 
 /** The SHO w_ top. */
 SHOW_TOP, 
 
 /** The SHO w_ use r_ history. */
 SHOW_USER_HISTORY, 
 
 /** The SIT e_ description. */
 SITE_DESCRIPTION, 
 
 /** The STAR t_ updat e_ job. */
 START_UPDATE_JOB, 
 
 /** The STOCKS. */
 STOCKS, 
 
 /** The SUMMARY. */
SUMMARY, 
 
 /** The SWEDE n_ arbetarepartie t_ socialdemokraterna. */
 SWEDEN_ARBETAREPARTIET_SOCIALDEMOKRATERNA, 
 
 /** The SWEDE n_ arbetarepartie t_ socialdemokratern a_ shortcode. */
 SWEDEN_ARBETAREPARTIET_SOCIALDEMOKRATERNA_SHORTCODE, 
 
 /** The SWEDE n_ centerpartiet. */
 SWEDEN_CENTERPARTIET, 
 
 /** The SWEDE n_ centerpartie t_ shortcode. */
 SWEDEN_CENTERPARTIET_SHORTCODE, 
 
 /** The SWEDE n_ folkpartie t_ liberalerna. */
 SWEDEN_FOLKPARTIET_LIBERALERNA, 
 
 /** The SWEDE n_ folkpartie t_ liberalern a_ shortcode. */
 SWEDEN_FOLKPARTIET_LIBERALERNA_SHORTCODE, 
 
 /** The SWEDE n_ kristdemokraterna. */
 SWEDEN_KRISTDEMOKRATERNA, 
 
 /** The SWEDE n_ kristdemokratern a_ shortcode. */
 SWEDEN_KRISTDEMOKRATERNA_SHORTCODE, 
 
 /** The SWEDE n_ milj o_ partie t_ d e_ grona. */
 SWEDEN_MILJO_PARTIET_DE_GRONA, 
 
 /** The SWEDE n_ milj o_ partie t_ d e_ gron a_ shortcode. */
 SWEDEN_MILJO_PARTIET_DE_GRONA_SHORTCODE, 
 
 /** The SWEDE n_ moderat a_ samlingspartiet. */
 SWEDEN_MODERATA_SAMLINGSPARTIET, 
 
 /** The SWEDE n_ moderat a_ samlingspartie t_ shortcode. */
 SWEDEN_MODERATA_SAMLINGSPARTIET_SHORTCODE,  
  
  /** The SWEDE n_ vanste r_ partiet. */
 SWEDEN_VANSTER_PARTIET,

 /** The SWEDE n_ vanste r_ partie t_ shortcode. */
 SWEDEN_VANSTER_PARTIET_SHORTCODE,

 /** The SWEDIS h_ parliamen t_ menu. */
 SWEDISH_PARLIAMENT_MENU,

 /** The TO p_ bes t_ friends. */
 TOP_BEST_FRIENDS, 
 
 /** The TO p_ wors t_ enemies. */
 TOP_WORST_ENEMIES, 
 
 /** The TRACKIN g_ politician s_ lik e_ bugs. */
 TRACKING_POLITICIANS_LIKE_BUGS, 
 
 /** The USAG e_ order. */
 USAGE_ORDER, 
 
 /** The USE r_ history. */
 USER_HISTORY, 
 
 /** The VOTE. */
 VOTE, 
 
 /** The VOT e_ occassion s_ compared. */
 VOTE_OCCASSIONS_COMPARED, 
 
 /** The VOT e_ occassion s_ lost. */
 VOTE_OCCASSIONS_LOST, 
 
 /** The VOT e_ position. */
 VOTE_POSITION, 
 
 /** The VOTES. */
 VOTES, 
 
 /** The WIKI. */
 WIKI, 
 
 /** The WIKILEAKS. */
 WIKILEAKS, 
 
 /** The WINNERS. */
 WINNERS, 
 
 /** The WINNIN g_ occassions. */
 WINNING_OCCASSIONS, 
 
 /** The WINNIN g_ percentage. */
 WINNING_PERCENTAGE, 
 
 /** The WINNIN g_ percentag e_ b y_ party. */
 WINNING_PERCENTAGE_BY_PARTY, 
 
 /** The WINNIN g_ side. */
 WINNING_SIDE,

/** The WINNIN g_ sid e_ i n_ party. */
 WINNING_SIDE_IN_PARTY, 
 
 /** The WINNIN g_ status. */
 WINNING_STATUS, 
 
 /** The WON. */
 WON, 
 
 /** The YES. */
 YES      
    }
    
    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The id. */
    private Long id;

    /** The language content. */
    private Set<LanguageContent> languageContent = new THashSet<LanguageContent>();

    
    /** The languages. */
    private Set<Language> languages = new THashSet<Language>();

    /** The name. */
    private String name;

    /** The portals. */
    private Set<Portal> portals = new THashSet<Portal>();

    /** The version. */
    private Long version=1L;

    /**
     * Find language.
     *
     * @param languageId the language id
     * @return the language
     */
    @Transient
    public Language findLanguage(Long languageId) {
        for (Language language : languages) {
            if (languageId.equals(language.getId())) {
                return language;
            }
        }
        return null;
    }

    /**
     * Find language content.
     *
     * @param languageContentId the language content id
     * @return the language content
     */
    @Transient
    public LanguageContent findLanguageContent(Long languageContentId) {
        for (LanguageContent languageContent : getLanguageContent()) {
            if (languageContentId.equals(languageContent.getId())) {
                return languageContent;
            }
        }
        return null;
   }

    /**
     * Find matching language.
     *
     * @param acceptLanguagesCsv the accept languages csv
     * @return the language
     */
    @Transient
    public Language findMatchingLanguage(final String acceptLanguagesCsv) {
        Language lowestMatched = null;
        
    	if (acceptLanguagesCsv != null) {
            for (Language language : getLanguages()) {
                if (language.getActiveByDefault() || acceptLanguagesCsv.toLowerCase().contains(language.getShortCode().toLowerCase())) {
                    
                	if (lowestMatched != null) {
                		if (language.getUsageOrder() < lowestMatched.getUsageOrder()) {
                			lowestMatched = language;
                		}                		
                	} else {
                		lowestMatched = language;
                	}
                }
            }
        }
        return lowestMatched;
    }

    /**
     * Find matching portal.
     *
     * @param headerHost the header host
     * @return the portal
     */
    @Transient
    public Portal findMatchingPortal(String headerHost) {
        if (headerHost != null) {
            for (Portal portal : portals) {
                if (portal.getActiveByDefault() || headerHost.toLowerCase().contains(
                        portal.getMatchesUrl().toLowerCase())) {
                    return portal;
                }
            }
        }
        return null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the language content.
     *
     * @return the language content
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "AgencyLanguageContent")
    @Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
    public Set<LanguageContent> getLanguageContent() {
        return languageContent;
    }

    /**
     * Gets the language content by key.
     *
     * @param key the key
     * @param language the language
     * @return the language content by key
     */
    @Transient
    public LanguageContent getLanguageContentByKey(Agency.LanguageContentKey key,Language language) {
        
        for (LanguageContent languageContent :getLanguageContent()) {
            if (key.equals(LanguageContentKey.valueOf(languageContent.getContentPropertyName())) && language.getId().equals(languageContent.getLanguage().getId())) {
                return languageContent;
            }
            
        }
        return null;
    }
    
    /**
     * Gets the language content by key.
     *
     * @param key the key
     * @param language the language
     * @return the language content by key
     */
    @Transient
    public LanguageContent getLanguageContentByKey(String key,Language language) {
        
        for (LanguageContent languageContent :getLanguageContent()) {
            if (key.equals(languageContent.getContentPropertyName()) && language.getId().equals(languageContent.getLanguage().getId())) {
                return languageContent;
            }
            
        }
        return null;
    }
    
    /**
     * Gets the language content by language.
     *
     * @param language the language
     * @return the language content by language
     */
    @Transient
    public Set<LanguageContent> getLanguageContentByLanguage(Language language) {
        Set<LanguageContent> languageSpecificContent= new THashSet<LanguageContent>();
        
        if (language != null) {
        	
	        for (LanguageContent languageContent :getLanguageContent()) {
	        	if (languageContent.getLanguage() != null) {
	        		if (language.getId().equals(languageContent.getLanguage().getId())) {
	        			languageSpecificContent.add(languageContent);
	        		}
	        	}        	
	        }
        }
        return languageSpecificContent;
    }
    


    /**
     * Gets the languages.
     *
     * @return the languages
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "AgencyLanguages")
    @Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
    public Set<Language> getLanguages() {
        return languages;
    }

    /**
     * Gets the name.
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * Gets the portal by id.
     *
     * @param portalId the portal id
     * @return the portal by id
     */
    @Transient
    public Portal getPortalById(Long portalId) {
        for (Portal portal : portals) {
            if (portalId.equals(portal.getId())) {
                return portal;
            }
        }
        return null;
    }

    /**
     * Gets the portals.
     *
     * @return the portals
     */
    @OneToMany(mappedBy = "agency", cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
    public Set<Portal> getPortals() {
        return portals;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Sets the language content.
     *
     * @param languageContent the new language content
     */
    public void setLanguageContent(Set<LanguageContent> languageContent) {
        this.languageContent = languageContent;
    }
    
    /**
     * Sets the languages.
     *
     * @param languages the new languages
     */
    public void setLanguages(Set<Language> languages) {
        this.languages = languages;
    }

    /**
     * Sets the name.
     *
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Sets the portals.
     *
     * @param portals the new portals
     */
    public void setPortals(Set<Portal> portals) {
        this.portals = portals;
    }

    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }

}
