/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.OneToMany;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

/**
 * The Class Language.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("Language")
public class Language extends AbstractAgencyConfiguration {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The Constant SWEDISH_LANGUAGE_CODE. */
    public static final String SWEDISH_LANGUAGE_CODE = "sv";

    /** The language contents. */
    private List<LanguageContent> languageContents = new ArrayList<LanguageContent>();

    /** The short code. */
    private String shortCode;
    
    /**
     * Instantiates a new language.
     */
    public Language() {
        super();
        setResourceType(ResourceType.Language);
    }

    /**
     * Gets the language contents.
     *
     * @return the language contents
     */
    @OneToMany(mappedBy = "language", cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    @Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
    public List<LanguageContent> getLanguageContents() {
        return languageContents;
    }

    /**
     * Gets the short code.
     *
     * @return the short code
     */
    public String getShortCode() {
        return shortCode;
    }

    /**
     * Sets the language contents.
     *
     * @param languageContents the new language contents
     */
    public void setLanguageContents(List<LanguageContent> languageContents) {
        this.languageContents = languageContents;
    }

    /**
     * Sets the short code.
     *
     * @param shortCode the new short code
     */
    public void setShortCode(String shortCode) {
        this.shortCode = shortCode;
    }

}
