/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.AbstractResource;

/**
 * The Class LanguageContent.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("LanguageContent")
public class LanguageContent extends AbstractResource {

    /**
     * The Enum LanguageContentType.
     */
    public enum LanguageContentType {

        /** The Agency. */
        Agency,

        /** The Portal. */
        Portal
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The content. */
    private String content;

    /** The content property name. */
    private String contentPropertyName;

    /** The description. */
    private String description;

    /** The language. */
    private Language language;

    /** The language content type. */
    private LanguageContentType languageContentType;

    /**
     * Instantiates a new language content.
     */
    public LanguageContent() {
        super();
        setResourceType(ResourceType.LanguageContent);
    }

    /**
     * Gets the content.
     *
     * @return the content
     */
    @Lob
    public String getContent() {
        return content;
    }

    /**
     * Gets the content property name.
     *
     * @return the content property name
     */
    public String getContentPropertyName() {
        return contentPropertyName;
    }

    /**
     * Gets the description.
     *
     * @return the description
     */
    public String getDescription() {
        return description;
    }

    /**
     * Gets the language.
     *
     * @return the language
     */
    @ManyToOne
    public Language getLanguage() {
        return language;
    }

    /**
     * Gets the language content type.
     *
     * @return the language content type
     */
    @Enumerated(EnumType.STRING)
    public LanguageContentType getLanguageContentType() {
        return languageContentType;
    }

    /**
     * Sets the content.
     *
     * @param content the new content
     */
    public void setContent(String content) {
        this.content = content;
    }

    /**
     * Sets the content property name.
     *
     * @param contentPropertyName the new content property name
     */
    public void setContentPropertyName(String contentPropertyName) {
        this.contentPropertyName = contentPropertyName;
    }

    /**
     * Sets the description.
     *
     * @param description the new description
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * Sets the language.
     *
     * @param language the new language
     */
    public void setLanguage(Language language) {
        this.language = language;
    }

    /**
     * Sets the language content type.
     *
     * @param languageContentType the new language content type
     */
    public void setLanguageContentType(LanguageContentType languageContentType) {
        this.languageContentType = languageContentType;
    }
}
