/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class PoliticalGame.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class PoliticalGame extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -1381199844545595026L;

    /** The game boards. */
    private Set<GameBoard> gameBoards;


    /** The id. */
    private Long id;

    /** The version. */
    private Long version=1L;
    
    /**
     * Instantiates a new political game.
     */
    public PoliticalGame() {
    }

    /**
     * Gets the game boards.
     *
     * @return the game boards
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "PoliticalGameBoards")
	public Set<GameBoard> getGameBoards() {
		return gameBoards;
	}


    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Sets the game boards.
     *
     * @param gameBoards the new game boards
     */
	public void setGameBoards(Set<GameBoard> gameBoards) {
		this.gameBoards = gameBoards;
	}

	/**
	 * Sets the id.
	 *
	 * @param id the new id
	 */
    public void setId(final Long id) {
        this.id = id;
    }

	/**
	 * Sets the version.
	 *
	 * @param version the new version
	 */
    public void setVersion(Long version) {
        this.version = version;
    }
}
