/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.common;

import java.util.Date;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.DiscriminatorColumn;
import javax.persistence.DiscriminatorType;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class User.
 */
@Entity
@Inheritance(strategy = InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name = "usertype", discriminatorType = DiscriminatorType.STRING)
@DiscriminatorValue("User")
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class User extends BaseEntity {

    /**
     * The Enum UserRole.
     */
    public enum UserRole {

        /** The ADMIN. */
        ADMIN,

        /** The ANYNOMOUS. */
        ANYNOMOUS,

        /** The USER. */
        USER,

        /** The VIP. */
        VIP
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -1381199844545595026L;

    /** The created date. */
    private Date createdDate;

    /** The id. */
    private Long id;

    /** The user role. */
    private UserRole userRole;

    /** The user sessions. */
    private List<UserSession> userSessions;

    /** The version. */
    private Long version=1L;

    /**
     * Instantiates a new user.
     */
    public User() {
    }

    /**
     * Gets the created date.
     *
     * @return the created date
     */
    public Date getCreatedDate() {
        return this.createdDate;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the user role.
     *
     * @return the user role
     */
    @Enumerated(EnumType.STRING)
    public UserRole getUserRole() {
        return userRole;
    }

    /**
     * Gets the user sessions.
     *
     * @return the user sessions
     */
    @OneToMany(mappedBy = "user", cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    @Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
    public List<UserSession> getUserSessions() {
        return userSessions;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Sets the created date.
     *
     * @param createdDate the new created date
     */
    @Temporal(TemporalType.DATE)
    public void setCreatedDate(final Date createdDate) {
        this.createdDate = createdDate;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(final Long id) {
        this.id = id;
    }

    /**
     * Sets the user role.
     *
     * @param userRole the new user role
     */
    public void setUserRole(final UserRole userRole) {
        this.userRole = userRole;
    }
    
    /**
     * Sets the user sessions.
     *
     * @param userSessions the new user sessions
     */
    public void setUserSessions(List<UserSession> userSessions) {
        this.userSessions = userSessions;
    }

    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }

}
