/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.application.impl.user;

import java.util.Date;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.application.impl.common.UserSession;

/**
 * The Class ParliamentMemberActionEvent.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("ParliamentMemberActionEvent")
public class ParliamentMemberActionEvent extends AbstractParliamentActionEvent {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The parliament member id. */
    private Long parliamentMemberId;

    /**
     * Instantiates a new parliament member action event.
     */
    public ParliamentMemberActionEvent() {
    }

    /**
     * Instantiates a new parliament member action event.
     *
     * @param createdDate the created date
     * @param userSession the user session
     * @param parliamentMemberId the parliament member id
     */
    public ParliamentMemberActionEvent(final Date createdDate,
            final UserSession userSession, final Long parliamentMemberId) {
        super(createdDate, userSession);
        this.parliamentMemberId = parliamentMemberId;
    }

    /**
     * Gets the parliament member id.
     *
     * @return the parliament member id
     */
    public Long getParliamentMemberId() {
        return parliamentMemberId;
    }

    /**
     * Sets the parliament member id.
     *
     * @param parliamentMemberId the new parliament member id
     */
    public void setParliamentMemberId(Long parliamentMemberId) {
        this.parliamentMemberId = parliamentMemberId;
    }
}
