/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.model.sweden.impl;

import javax.persistence.DiscriminatorColumn;
import javax.persistence.DiscriminatorType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.Transient;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class AbstractBallotMetaData.
 */
@Entity
@Inheritance(strategy = InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name = "ballotMetaDataType", discriminatorType = DiscriminatorType.STRING)
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public abstract class AbstractBallotMetaData extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 6065382653371757540L;

	/** The absent votes. */
    protected long absentVotes = 0;

    /** The id. */
    private Long id;

    /** The neutral votes. */
    protected long neutralVotes = 0;
    
    /** The no votes. */
    protected long noVotes = 0;

    /** The total votes. */
    protected long totalVotes = 0;

    /** The version. */
    private Long version=1L;

    /** The yes votes. */
    protected long yesVotes = 0;

    /**
     * Instantiates a new abstract ballot meta data.
     */
    public AbstractBallotMetaData() {
		super();
	}

    /**
     * Gets the absent votes.
     *
     * @return the absent votes
     */
    public long getAbsentVotes() {
        return absentVotes;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the neutral votes.
     *
     * @return the neutral votes
     */
    public long getNeutralVotes() {
        return neutralVotes;
    }

    /**
     * Gets the no votes.
     *
     * @return the no votes
     */
    public long getNoVotes() {
        return noVotes;
    }

    /**
     * Gets the total votes.
     *
     * @return the total votes
     */
    public long getTotalVotes() {
        return totalVotes;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Gets the yes votes.
     *
     * @return the yes votes
     */
    public long getYesVotes() {
        return yesVotes;
    }

    /**
     * New vote.
     *
     * @param vote the vote
     */
    @Transient
    public void newVote(Vote vote) {
        totalVotes++;
        if (vote.getPosition() != null) {
            if (vote.getPosition().equals(Vote.Position.Absent)) {
                absentVotes++;
            } else if (vote.getPosition().equals(Vote.Position.Neutral)) {
                neutralVotes++;
            } else if (vote.getPosition().equals(Vote.Position.Yes)) {
                yesVotes++;
            } else if (vote.getPosition().equals(Vote.Position.No)) {
                noVotes++;
            }
        }
    }

    /**
     * Sets the absent votes.
     *
     * @param absentVotes the new absent votes
     */
    public void setAbsentVotes(long absentVotes) {
        this.absentVotes = absentVotes;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }

	/**
	 * Sets the neutral votes.
	 *
	 * @param neutralVotes the new neutral votes
	 */
    public void setNeutralVotes(long neutralVotes) {
        this.neutralVotes = neutralVotes;
    }


    /**
     * Sets the no votes.
     *
     * @param noVotes the new no votes
     */
    public void setNoVotes(long noVotes) {
        this.noVotes = noVotes;
    }


    /**
     * Sets the total votes.
     *
     * @param totalVotes the new total votes
     */
    public void setTotalVotes(long totalVotes) {
        this.totalVotes = totalVotes;
    }


    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }

    /**
     * Sets the yes votes.
     *
     * @param yesVotes the new yes votes
     */
    public void setYesVotes(long yesVotes) {
        this.yesVotes = yesVotes;
    }
    
}
