/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.model.sweden.impl;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.Transient;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.sweden.impl.Vote.Position;

/**
 * The Class AbstractBallotResult.
 */
@Entity
@DiscriminatorValue("AbstractBallotResult")
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public abstract class AbstractBallotResult extends AbstractBallotMetaData {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 6065382653371757540L;

	/** The opponent votes. */
    protected long opponentVotes;
    
    /** The winning position. */
    protected Position winningPosition;
    
    /** The winning votes. */
    protected long winningVotes;

    /**
     * Instantiates a new abstract ballot result.
     */
    public AbstractBallotResult() {
		super();
	}

    /**
     * Calc winning position.
     */
    @Transient
    public void calcWinningPosition() {
        if (yesVotes > noVotes) {
            setWinningPosition(Position.Yes);
            opponentVotes = this.noVotes;
            winningVotes = this.yesVotes;
        } else if (noVotes > yesVotes) {
            setWinningPosition(Position.No);
            opponentVotes = this.yesVotes;
            winningVotes = this.noVotes;
        } else {
            setWinningPosition(Position.Neutral);
            opponentVotes = this.yesVotes + this.noVotes;
            winningVotes = this.neutralVotes;
        }
    }

    /**
     * Gets the opponent votes.
     *
     * @return the opponent votes
     */
	public long getOpponentVotes() {
		return opponentVotes;
	}
    
    /**
     * Gets the winning position.
     *
     * @return the winning position
     */
    @Enumerated(EnumType.STRING)
    public Position getWinningPosition() {
        return winningPosition;
    }

	/**
	 * Gets the winning votes.
	 *
	 * @return the winning votes
	 */
	public long getWinningVotes() {
		return winningVotes;
	}

	/**
	 * Sets the opponent votes.
	 *
	 * @param opponentVotes the new opponent votes
	 */
	public void setOpponentVotes(long opponentVotes) {
		this.opponentVotes = opponentVotes;
	}

	/**
	 * Sets the winning position.
	 *
	 * @param winningPosition the new winning position
	 */
    public void setWinningPosition(Position winningPosition) {
        this.winningPosition = winningPosition;
    }

	/**
	 * Sets the winning votes.
	 *
	 * @param winningVotes the new winning votes
	 */
	public void setWinningVotes(long winningVotes) {
		this.winningVotes = winningVotes;
	}

}
