/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import gnu.trove.THashSet;

import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class Parliament.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Parliament extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;


    /** The id. */
    private Long id;

    /** The version. */
    private Long version=1L;
    
    /** The name. */
    private String name;

    /** The description. */
    private String description;
    
    /** The url. */
    private String url;

    /** The parliament years. */
    private Set<ParliamentYear> parliamentYears = new THashSet<ParliamentYear>();
    
    /** The committees. */
    private Set<Committee> committees = new THashSet<Committee>();
    
    
    /** The elections. */
    private Set<Election> elections = new THashSet<Election>();    
    
    /**
     * Instantiates a new parliament.
     */
	public Parliament() {
		super();
	}

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the name.
     *
     * @return the name
     */
	public String getName() {
		return name;
	}


    /**
     * Gets the parliament years.
     *
     * @return the parliament years
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "ParliamentYears")
	public Set<ParliamentYear> getParliamentYears() {
		return parliamentYears;
	}

	/**
	 * Gets the short code.
	 *
	 * @return the short code
	 */
	public String getShortCode() {
		return description;
	}

	/* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

	/**
	 * Sets the id.
	 *
	 * @param id the new id
	 */
    public void setId(Long id) {
        this.id = id;
    }

	/**
	 * Sets the name.
	 *
	 * @param name the new name
	 */
	public void setName(String name) {
		this.name = name;
	}


    /**
     * Sets the short code.
     *
     * @param shortCode the new short code
     */
	public void setShortCode(String shortCode) {
		this.description = shortCode;
	}

	/**
	 * Sets the version.
	 *
	 * @param version the new version
	 */
    public void setVersion(Long version) {
        this.version = version;
    }

	/**
	 * Gets the description.
	 *
	 * @return the description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * Sets the description.
	 *
	 * @param description the new description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Gets the url.
	 *
	 * @return the url
	 */
	public String getUrl() {
		return url;
	}

	/**
	 * Sets the url.
	 *
	 * @param url the new url
	 */
	public void setUrl(String url) {
		this.url = url;
	}

    /**
     * Gets the elections.
     *
     * @return the elections
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "ParliamentElections")
	public Set<Election> getElections() {
		return elections;
	}

	/**
	 * Sets the elections.
	 *
	 * @param elections the new elections
	 */
	public void setElections(Set<Election> elections) {
		this.elections = elections;
	}

	/**
	 * Sets the parliament years.
	 *
	 * @param parliamentYears the new parliament years
	 */
	public void setParliamentYears(Set<ParliamentYear> parliamentYears) {
		this.parliamentYears = parliamentYears;
	}

    /**
     * Gets the committees.
     *
     * @return the committees
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @JoinTable(name = "ParliamentCommittees")
	public Set<Committee> getCommittees() {
		return committees;
	}

	/**
	 * Sets the committees.
	 *
	 * @param committees the new committees
	 */
	public void setCommittees(Set<Committee> committees) {
		this.committees = committees;
	}


}
