/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import java.util.Date;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class ParliamentMemberVoteCompareResult.
 */
@Entity
@Table(uniqueConstraints = { @UniqueConstraint(columnNames = {
        "parliamentMember_id", "opponentParliamentMember_id" }) })
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class ParliamentMemberVoteCompareResult extends BaseEntity {

    /** The Constant NO_RESULT. */
    public static final float NO_RESULT = 1.0f;

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The datum. */
    private Date datum;

    /** The id. */
    private Long id;

    /** The opponent parliament member. */
    private ParliamentMember opponentParliamentMember;

    /** The parliament member. */
    private ParliamentMember parliamentMember;

    /** The result. */
    private float result = NO_RESULT;

    /** The version. */
    private Long version=1L;

    /** The votes compared. */
    private int votesCompared;

    /**
     * Instantiates a new parliament member vote compare result.
     */
    public ParliamentMemberVoteCompareResult() {
        super();
    }

    /**
     * Instantiates a new parliament member vote compare result.
     *
     * @param datum the datum
     * @param votesCompared the votes compared
     * @param result the result
     * @param parliamentMember the parliament member
     * @param opponentParliamentMember the opponent parliament member
     */
    public ParliamentMemberVoteCompareResult(Date datum, int votesCompared,
            float result, ParliamentMember parliamentMember,
            ParliamentMember opponentParliamentMember) {
        super();
        this.datum = datum;
        this.votesCompared = votesCompared;
        this.result = result;
        this.parliamentMember = parliamentMember;
        this.opponentParliamentMember = opponentParliamentMember;
    }

    /**
     * Gets the datum.
     *
     * @return the datum
     */
    @Temporal(TemporalType.DATE)
    public Date getDatum() {
        return datum;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the opponent parliament member.
     *
     * @return the opponent parliament member
     */
    @ManyToOne
    public ParliamentMember getOpponentParliamentMember() {
        return opponentParliamentMember;
    }

    /**
     * Gets the parliament member.
     *
     * @return the parliament member
     */
    @ManyToOne
    public ParliamentMember getParliamentMember() {
        return parliamentMember;
    }

    /**
     * Gets the result.
     *
     * @return the result
     */
    public float getResult() {
        return result;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

    /**
     * Gets the votes compared.
     *
     * @return the votes compared
     */
    public int getVotesCompared() {
        return votesCompared;
    }

    /**
     * Sets the datum.
     *
     * @param datum the new datum
     */
    public void setDatum(Date datum) {
        this.datum = datum;
    }

    /**
     * Sets the id.
     *
     * @param id the new id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Sets the opponent parliament member.
     *
     * @param opponentParliamentMember the new opponent parliament member
     */
    public void setOpponentParliamentMember(
            ParliamentMember opponentParliamentMember) {
        this.opponentParliamentMember = opponentParliamentMember;
    }

    /**
     * Sets the parliament member.
     *
     * @param parliamentMember the new parliament member
     */
    public void setParliamentMember(ParliamentMember parliamentMember) {
        this.parliamentMember = parliamentMember;
    }

    /**
     * Sets the result.
     *
     * @param result the new result
     */
    public void setResult(float result) {
        this.result = result;
    }
    
    /**
     * Sets the version.
     *
     * @param version the new version
     */
    public void setVersion(Long version) {
        this.version = version;
    }

    /**
     * Sets the votes compared.
     *
     * @param votesCompared the new votes compared
     */
    public void setVotesCompared(int votesCompared) {
        this.votesCompared = votesCompared;
    }

}
