/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import gnu.trove.THashSet;

import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;
import javax.persistence.Version;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.core.impl.BaseEntity;

/**
 * The Class ParliamentYear.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class ParliamentYear extends BaseEntity {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;


    /** The id. */
    private Long id;

    /** The name. */
    private String name;
    
    /** The committee reports. */
    private Set<CommitteeReport> committeeReports = new THashSet<CommitteeReport>();
    
    /** The short code. */
    private String shortCode;
    
    /** The version. */
    private Long version=1L;
    
    /**
     * Instantiates a new parliament year.
     */
	public ParliamentYear() {
		super();
	}

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.model.core.BaseEntity#getId()
     */
    @Override
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    public Long getId() {
        return id;
    }

    /**
     * Gets the name.
     *
     * @return the name
     */
	public String getName() {
		return name;
	}


    /**
     * Gets the committee reports.
     *
     * @return the committee reports
     */
    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    @JoinTable(name = "ParliamentYearCommitteeReports")
	public Set<CommitteeReport> getCommitteeReports() {
		return committeeReports;
	}

	/**
	 * Gets the short code.
	 *
	 * @return the short code
	 */
	public String getShortCode() {
		return shortCode;
	}

	/* (non-Javadoc)
     * @see com.hack23.cia.model.core.BaseEntity#getVersion()
     */
    @Override
    @Version
    public Long getVersion() {
        return version;
    }

	/**
	 * Sets the id.
	 *
	 * @param id the new id
	 */
    public void setId(Long id) {
        this.id = id;
    }

	/**
	 * Sets the name.
	 *
	 * @param name the new name
	 */
	public void setName(String name) {
		this.name = name;
	}

    /**
     * Sets the short code.
     *
     * @param shortCode the new short code
     */
	public void setShortCode(String shortCode) {
		this.shortCode = shortCode;
	}

	/**
	 * Sets the version.
	 *
	 * @param version the new version
	 */
    public void setVersion(Long version) {
        this.version = version;
    }

	/**
	 * Sets the committee reports.
	 *
	 * @param committeeReports the new committee reports
	 */
	public void setCommitteeReports(Set<CommitteeReport> committeeReports) {
		this.committeeReports = committeeReports;
	}
}
