/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.model.sweden.impl;

import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.ManyToOne;
import javax.persistence.Transient;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import com.hack23.cia.model.sweden.impl.Vote.Position;

/**
 * The Class PartyBallotResult.
 */
@Entity
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@DiscriminatorValue("PartyBallotMetaData")
public class PartyBallotResult extends AbstractBallotResult {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -7843524383033778447L;

    /** The political party. */
    private PoliticalParty politicalParty;
    
    /**
     * Instantiates a new party ballot result.
     */
    public PartyBallotResult() {
		super();
	}

	/**
	 * Gets the political party.
	 *
	 * @return the political party
	 */
	@ManyToOne
	public PoliticalParty getPoliticalParty() {
		return politicalParty;
	}

	/**
	 * Checks if is rebel vote.
	 *
	 * @param vote the vote
	 * @return true, if is rebel vote
	 */
	@Transient
	public boolean isRebelVote(Vote vote) {
		if (vote.getPosition().equals(Position.Absent)) {
			return false;
		} else {
			return !getWinningPosition().equals(vote.getPosition());
		}
	}

	/**
	 * Sets the political party.
	 *
	 * @param politicalParty the new political party
	 */
	public void setPoliticalParty(PoliticalParty politicalParty) {
		this.politicalParty = politicalParty;
	}
}
