/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.api.admin;

import com.hack23.cia.model.application.impl.admin.LanguageContentActionEvent.Operation;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.LanguageContent;

/**
 * The Class LanguageContentRequest.
 */
public class LanguageContentRequest extends AbstractAgencyRequest {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The language content. */
    private final LanguageContent languageContent;

    /** The operation. */
    private final Operation operation;

    /**
     * Instantiates a new language content request.
     *
     * @param userSessionId the user session id
     * @param operation the operation
     * @param agency the agency
     * @param languageContent the language content
     */
    public LanguageContentRequest(final Long userSessionId, final Operation operation,
            final Agency agency, final LanguageContent languageContent) {
        super(userSessionId,agency);
        this.operation = operation;
        this.languageContent = languageContent;
    }

    /**
     * Gets the language content.
     *
     * @return the language content
     */
    public final LanguageContent getLanguageContent() {
        return languageContent;
    }

    /**
     * Gets the operation.
     *
     * @return the operation
     */
    public final Operation getOperation() {
        return operation;
    }
}
