/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.api.application;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.service.api.common.AbstractServiceResponse;

/**
 * The Class ApplicationResponse.
 */
public class ApplicationResponse extends AbstractServiceResponse {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The agency. */
    private final Agency agency;

    /** The last decided commitee reports. */
    private final List<CommitteeReport> lastDecidedCommiteeReports;

	/** The political parties. */
	private final List<PoliticalParty> politicalParties;

    /**
     * Instantiates a new application response.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     * @param lastDecidedCommiteeReports the last decided commitee reports
     * @param politicalParties the political parties
     */
    public ApplicationResponse(final UserSessionDTO userSessionDTO,
            final Agency agency,
            final List<CommitteeReport> lastDecidedCommiteeReports,final List<PoliticalParty> politicalParties) {
       super(userSessionDTO);
        this.agency = agency;
        this.lastDecidedCommiteeReports = lastDecidedCommiteeReports;
		this.politicalParties = politicalParties;
    }

    /**
     * Gets the agency.
     *
     * @return the agency
     */
    public final Agency getAgency() {
        return this.agency;
    }

    /**
     * Gets the last decided commitee reports.
     *
     * @return the last decided commitee reports
     */
    public final List<CommitteeReport> getLastDecidedCommiteeReports() {
        return this.lastDecidedCommiteeReports;
    }

    /**
     * Gets the political parties.
     *
     * @return the political parties
     */
	public final List<PoliticalParty> getPoliticalParties() {
		return politicalParties;
	}

	/*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.api.ServiceResponse#getResult()
     */
    @Override
    public final ServiceResult getResult() {
        return ServiceResult.SUCCESS;
    }
}
