/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.api.user;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.RegisterInformation;
import com.hack23.cia.model.sweden.impl.Vote;

/**
 * The Class ParliamentMemberResponse.
 */
public class ParliamentMemberResponse extends AbstractParliamentResponse {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The enemy list. */
    private final List<ParliamentMemberVoteCompareResult> enemyList;

    /** The enemy party list. */
    private final List<ParliamentMemberVoteCompareResult> enemyPartyList;

    /** The friend list. */
    private final List<ParliamentMemberVoteCompareResult> friendList;

    /** The friend party list. */
    private final List<ParliamentMemberVoteCompareResult> friendPartyList;

    /** The parliament member. */
    private final ParliamentMember parliamentMember;

    /** The register information. */
    private final RegisterInformation registerInformation;

    /** The votes. */
    private final List<Vote> votes;

    /**
     * Instantiates a new parliament member response.
     *
     * @param userSessionDTO the user session dto
     * @param parliamentMember the parliament member
     * @param friendList the friend list
     * @param enemyList the enemy list
     * @param friendPartyList the friend party list
     * @param enemyPartyList the enemy party list
     * @param votes the votes
     * @param registerInformation the register information
     */
    public ParliamentMemberResponse(final UserSessionDTO userSessionDTO,
            final ParliamentMember parliamentMember,
            final List<ParliamentMemberVoteCompareResult> friendList,
            final List<ParliamentMemberVoteCompareResult> enemyList,
            final List<ParliamentMemberVoteCompareResult> friendPartyList,
            final List<ParliamentMemberVoteCompareResult> enemyPartyList,
            final List<Vote> votes,
            final RegisterInformation registerInformation) {
       super(userSessionDTO);
        this.parliamentMember = parliamentMember;
        this.friendList = friendList;
        this.enemyList = enemyList;
        this.friendPartyList = friendPartyList;
        this.enemyPartyList = enemyPartyList;
        this.votes = votes;
        this.registerInformation = registerInformation;
    }

    /**
     * Gets the enemy list.
     *
     * @return the enemy list
     */
    public final List<ParliamentMemberVoteCompareResult> getEnemyList() {
        return enemyList;
    }

    /**
     * Gets the enemy party list.
     *
     * @return the enemy party list
     */
    public final List<ParliamentMemberVoteCompareResult> getEnemyPartyList() {
        return enemyPartyList;
    }

    /**
     * Gets the friend list.
     *
     * @return the friend list
     */
    public final List<ParliamentMemberVoteCompareResult> getFriendList() {
        return friendList;
    }

    /**
     * Gets the friend party list.
     *
     * @return the friend party list
     */
    public final List<ParliamentMemberVoteCompareResult> getFriendPartyList() {
        return friendPartyList;
    }

    /**
     * Gets the parliament member.
     *
     * @return the parliament member
     */
    public final ParliamentMember getParliamentMember() {
        return parliamentMember;
    }

    /**
     * Gets the register information.
     *
     * @return the register information
     */
    public final RegisterInformation getRegisterInformation() {
        return registerInformation;
    }

    /**
     * Gets the votes.
     *
     * @return the votes
     */
    public final List<Vote> getVotes() {
        return votes;
    }
}
