/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.dao;

import java.util.List;

import org.hibernate.HibernateException;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.model.sweden.impl.Ballot.ImportStatus;

/**
 * The Class BallotDAOImpl.
 */
public class BallotDAOImpl extends GenericHibernateDAO<Ballot, Long> implements
        BallotDAO {

    /**
     * Instantiates a new ballot dao impl.
     */
    public BallotDAOImpl() {
        super(Ballot.class);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.BallotDAO#getAllCompleted()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<Ballot> getAllCompleted() {
        try {
            return getSession().createCriteria(Ballot.class).add(
                    Restrictions.eq("importStatus", ImportStatus.Completed)) //$NON-NLS-1$
                    .setCacheable(true).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.CommiteeReportDAO#getAllCreated()
     */
    @SuppressWarnings("unchecked")
    public final List<Ballot> getAllCreated() {
        try {
            return getSession().createCriteria(Ballot.class).add(
                    Restrictions.eq("importStatus", ImportStatus.Created)) //$NON-NLS-1$
                    .setCacheable(true).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.BallotDAO#getAllOrderedByWeek()
     */
    @SuppressWarnings("unchecked")
    public final List<Ballot> getAllOrderedByWeek() {
        return this
                .getHibernateTemplate()
                .find(
                        "select week(ballot.datum),ballot from Ballot ballot order by week(ballot.datum)"); //$NON-NLS-1$
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.BallotDAO#getLast()
     */
    @Override
    public final Ballot getLast() {
        try {
            return ((Vote) getSession().createCriteria(Vote.class)
                    .setMaxResults(1).addOrder((Order.desc("datum"))) //$NON-NLS-1$
                    .setCacheable(true).setMaxResults(1).uniqueResult())
                    .getBallot();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

}
