/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.dao;

import java.util.List;

import org.hibernate.HibernateException;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.CommitteeReport.ImportStatus;

/**
 * The Class CommitteeReportDAOImpl.
 */
public class CommitteeReportDAOImpl extends
        GenericHibernateDAO<CommitteeReport, Long> implements
        CommitteeReportDAO {

    /**
     * Instantiates a new committee report dao impl.
     */
    public CommitteeReportDAOImpl() {
        super(CommitteeReport.class);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.CommiteeReportDAO#findByName(java.lang.String)
     */
    @Transactional(readOnly = true)
    public final CommitteeReport findByName(final String name) {
        try {
            return (CommitteeReport) getSession()
                    .createCriteria(CommitteeReport.class)
                    .add(Restrictions.eq("name", name)).setCacheable(true).uniqueResult(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.CommiteeReportDAO#getAllCreated()
     */
    @SuppressWarnings("unchecked")
    public final List<CommitteeReport> getAllCreated() {
        try {
            return getSession().createCriteria(CommitteeReport.class).add(
                    Restrictions.eq("importStatus", ImportStatus.Created)) //$NON-NLS-1$
                    .addOrder(Order.asc("name")).setCacheable(true).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.CommiteeReportDAO#getAllLastDecided()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<CommitteeReport> getAllLastDecided() {
        try {
            return getSession().createCriteria(CommitteeReport.class).addOrder(
                    Order.desc("decisionDate")).setCacheable(true).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.CommiteeReportDAO#getLastDecided()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<CommitteeReport> getLastDecided() {
        try {
            return getSession()
                    .createCriteria(CommitteeReport.class)
                    .add(
                            Restrictions.eq(
                                    "importStatus", ImportStatus.Completed)) //$NON-NLS-1$
                    .addOrder(Order.desc("decisionDate")).setCacheable(true).setMaxResults(10).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

}
