/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.dao;

import java.util.Collection;
import java.util.List;

import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.Vote;

/**
 * The Interface ParliamentMemberDAO.
 */
public interface ParliamentMemberDAO extends GenericDAO<ParliamentMember, Long> {

    /**
     * Delete all parliament member vote compare results.
     */
    void deleteAllParliamentMemberVoteCompareResults();

    /**
     * Find last votes.
     *
     * @param id the id
     * @return the list
     */
    List<Vote> findLastVotes(Long id);

    /**
     * Find last votes by ballot id.
     *
     * @param id the id
     * @return the list
     */
    List<Vote> findLastVotesByBallotId(final Long id);

    /**
     * Find list by name.
     *
     * @param searchString the search string
     * @return the list
     */
    List<ParliamentMember> findListByName(String searchString);

    /**
     * Find votes.
     *
     * @param id the id
     * @return the list
     */
    List<Vote> findVotes(Long id);

    /**
     * Gets the current list.
     *
     * @return the current list
     */
    List<ParliamentMember> getCurrentList();

    /**
     * Gets the current top list absent.
     *
     * @param number the number
     * @return the current top list absent
     */
    List<ParliamentMember> getCurrentTopListAbsent(int number);

    /**
     * Gets the current top list absent by party.
     *
     * @param i the i
     * @param party the party
     * @return the current top list absent by party
     */
    List<ParliamentMember> getCurrentTopListAbsentByParty(int i, String party);

    /**
     * Gets the current top list losers.
     *
     * @param i the i
     * @return the current top list losers
     */
    List<ParliamentMember> getCurrentTopListLosers(int i);

    /**
     * Gets the current top list losers by party.
     *
     * @param i the i
     * @param party the party
     * @return the current top list losers by party
     */
    List<ParliamentMember> getCurrentTopListLosersByParty(int i, String party);

    /**
     * Gets the current top list loyal.
     *
     * @param i the i
     * @return the current top list loyal
     */
    List<ParliamentMember> getCurrentTopListLoyal(int i);

    /**
     * Gets the current top list loyal by party.
     *
     * @param i the i
     * @param party the party
     * @return the current top list loyal by party
     */
    List<ParliamentMember> getCurrentTopListLoyalByParty(int i, String party);

    /**
     * Gets the current top list present.
     *
     * @param i the i
     * @return the current top list present
     */
    List<ParliamentMember> getCurrentTopListPresent(int i);

    /**
     * Gets the current top list present by party.
     *
     * @param i the i
     * @param party the party
     * @return the current top list present by party
     */
    List<ParliamentMember> getCurrentTopListPresentByParty(int i, String party);

    /**
     * Gets the current top list rebels.
     *
     * @param i the i
     * @return the current top list rebels
     */
    List<ParliamentMember> getCurrentTopListRebels(int i);

    /**
     * Gets the current top list rebels by party.
     *
     * @param i the i
     * @param party the party
     * @return the current top list rebels by party
     */
    List<ParliamentMember> getCurrentTopListRebelsByParty(int i, String party);

    /**
     * Gets the current top list winners.
     *
     * @param i the i
     * @return the current top list winners
     */
    List<ParliamentMember> getCurrentTopListWinners(int i);

    /**
     * Gets the current top list winners by party.
     *
     * @param i the i
     * @param party the party
     * @return the current top list winners by party
     */
    List<ParliamentMember> getCurrentTopListWinnersByParty(int i, String party);

    /**
     * Gets the positions.
     *
     * @param parliamentMember the parliament member
     * @return the positions
     */
    List<Vote.Position> getPositions(ParliamentMember parliamentMember);

    /**
     * Gets the top enemies.
     *
     * @param parliamentMember the parliament member
     * @return the top enemies
     */
    List<ParliamentMemberVoteCompareResult> getTopEnemies(
            ParliamentMember parliamentMember);

    /**
     * Gets the top enemies same party.
     *
     * @param parliamentMember the parliament member
     * @return the top enemies same party
     */
    List<ParliamentMemberVoteCompareResult> getTopEnemiesSameParty(
            ParliamentMember parliamentMember);

    /**
     * Gets the top friends.
     *
     * @param parliamentMember the parliament member
     * @return the top friends
     */
    List<ParliamentMemberVoteCompareResult> getTopFriends(
            ParliamentMember parliamentMember);

    /**
     * Gets the top friends in same party.
     *
     * @param parliamentMember the parliament member
     * @return the top friends in same party
     */
    List<ParliamentMemberVoteCompareResult> getTopFriendsInSameParty(
            ParliamentMember parliamentMember);

    /**
     * Save all.
     *
     * @param list the list
     */
    void saveAll(Collection<ParliamentMember> list);

    /**
     * Save parliament member vote compare result.
     *
     * @param result the result
     */
    void saveParliamentMemberVoteCompareResult(
            Collection<ParliamentMemberVoteCompareResult> result);
}
