/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.dao;

import java.util.Collection;
import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.FetchMode;
import org.hibernate.HibernateException;
import org.hibernate.criterion.DetachedCriteria;
import org.hibernate.criterion.LogicalExpression;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Property;
import org.hibernate.criterion.Restrictions;
import org.hibernate.criterion.SimpleExpression;

import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.Vote;

/**
 * The Class ParliamentMemberDAOImpl.
 */
public class ParliamentMemberDAOImpl extends
        GenericHibernateDAO<ParliamentMember, Long> implements
        ParliamentMemberDAO {

    /**
     * Instantiates a new parliament member dao impl.
     */
    public ParliamentMemberDAOImpl() {
        super(ParliamentMember.class);
    }

    /**
     * Creates the parliament member vote compare result top base critera.
     *
     * @return the criteria
     */
    private Criteria createParliamentMemberVoteCompareResultTopBaseCritera() {
        return getSession().createCriteria(
                ParliamentMemberVoteCompareResult.class).createAlias(
                "opponentParliamentMember", "opponent").setCacheable(true) //$NON-NLS-1$ //$NON-NLS-2$
                .setMaxResults(10);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.dao.ParliamentMemberDAO#
     * deleteAllParliamentMemberVoteCompareResults()
     */
    public final void deleteAllParliamentMemberVoteCompareResults() {
        getHibernateTemplate().bulkUpdate(
                "delete from ParliamentMemberVoteCompareResult"); //$NON-NLS-1$
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#findLastVotes(java.lang
     * .Long)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<Vote> findLastVotes(final Long id) {
        try {
            return getSession()
                    .createCriteria(Vote.class)
                    .add(Restrictions.eq("parliamentMember.id", id)).addOrder( //$NON-NLS-1$
                            Order.desc("datum")).setMaxResults(30).setCacheable(true).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#findLastVotes(java.lang
     * .Long)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<Vote> findLastVotesByBallotId(final Long id) {
        try {
            return getSession()
                    .createCriteria(Vote.class)
                    .add(Restrictions.eq("ballot.id", id)).addOrder( //$NON-NLS-1$
                            Order.desc("parliamentMember.id")).setFetchMode("ballot", FetchMode.JOIN) //$NON-NLS-1$ //$NON-NLS-2$
                    .setMaxResults(349).setCacheable(true).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#findListByName(java.lang
     * .String)
     */
    @Override
    public final List<ParliamentMember> findListByName(final String searchString) {
        DetachedCriteria findByName = DetachedCriteria
                .forClass(ParliamentMember.class);
        findByName.add(Restrictions.ilike("name", "%" + searchString + "%")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
        findByName.addOrder(Order.asc("name")); //$NON-NLS-1$

        @SuppressWarnings("unchecked")
        List<ParliamentMember> result = this.getHibernateTemplate()
                .findByCriteria(findByName);

        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#findVotes(java.lang.Long)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<Vote> findVotes(final Long id) {
        try {
            return getSession().createCriteria(Vote.class).add(
                    Restrictions.eq("parliamentMember.id", id)).addOrder( //$NON-NLS-1$
                    Order.desc("datum")).setCacheable(true).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentListAt()
     */
    @SuppressWarnings("unchecked")
    public final List<ParliamentMember> getCurrentList() {
        try {
            return getSession()
                    .createCriteria(ParliamentMember.class)
                    .createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord")
                    .addOrder(Order.desc("parliamentMemberBallotRecord.lastVoteDate")).setCacheable(true).setMaxResults( //$NON-NLS-1$
                            349).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopList(int)
     */
    @SuppressWarnings("unchecked")
    public final List<ParliamentMember> getCurrentTopListAbsent(final int number) {
        try {

            return getSession().createCriteria(ParliamentMember.class)
               		.createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord")                 
                    .addOrder(Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                            Order.desc("parliamentMemberBallotRecord.percentageAbsent")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(number).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListByParty
     * (int, java.lang.String)
     */
    @SuppressWarnings("unchecked")
    public final List<ParliamentMember> getCurrentTopListAbsentByParty(
            final int i, final String party) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord").add(
                    Restrictions.eq("party", party)).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.percentageAbsent")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListLosers
     * (int)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListLosers(final int i) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord")
                    .addOrder(Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                            Order.desc("parliamentMemberBallotRecord.opponent")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.dao.ParliamentMemberDAO#
     * getCurrentTopListLosersByParty(int, java.lang.String)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListLosersByParty(
            final int i, final String party) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord").add(
                    Restrictions.eq("party", party)).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.opponent")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListLoyal
     * (int)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListLoyal(final int i) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord")
                    .addOrder(Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                            Order.desc("parliamentMemberBallotRecord.percentageLoyal")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListLoyalByParty
     * (int, java.lang.String)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListLoyalByParty(
            final int i, final String party) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord").add(
                    Restrictions.eq("party", party)).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.percentageLoyal")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListPresent
     * (int)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListPresent(final int i) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord")
                    .addOrder(Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                            Order.desc("parliamentMemberBallotRecord.percentagePresent")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.dao.ParliamentMemberDAO#
     * getCurrentTopListPresentByParty(int, java.lang.String)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListPresentByParty(
            final int i, final String party) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord").add(
                    Restrictions.eq("party", party)).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.percentagePresent")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListRebels
     * (int)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListRebels(final int i) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord")
                    .addOrder(Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                            Order.desc("parliamentMemberBallotRecord.percentageRebel")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListRebelsByParty
     * (int, java.lang.String)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListRebelsByParty(
            final int i, final String party) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord").add(
                    Restrictions.eq("party", party)).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.percentageRebel")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getCurrentTopListWinners
     * (int)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListWinners(final int i) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord")
                    .addOrder(Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                            Order.desc("parliamentMemberBallotRecord.percentageWinning")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.dao.ParliamentMemberDAO#
     * getCurrentTopListWinnersByParty(int, java.lang.String)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMember> getCurrentTopListWinnersByParty(
            final int i, final String party) {
        try {

            return getSession().createCriteria(ParliamentMember.class).createAlias("parliamentMemberBallotRecord", "parliamentMemberBallotRecord").add(
                    Restrictions.eq("party", party)).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.lastVoteDate")).addOrder( //$NON-NLS-1$
                    Order.desc("parliamentMemberBallotRecord.percentageWinning")).setCacheable(true) //$NON-NLS-1$
                    .setMaxResults(i).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getPositions(com.hack23
     * .cia.model.sweden.ParliamentMember)
     */
    @SuppressWarnings("unchecked")
    public final List<Vote.Position> getPositions(
            final ParliamentMember parliamentMember) {
        this.getHibernateTemplate().setCacheQueries(true);
        List<Vote.Position> result = getHibernateTemplate()
                .find(
                        "select vote.position from Vote as vote where vote.parliamentMember.id= ? order by vote.datum desc,vote.ballot.id", //$NON-NLS-1$
                        parliamentMember.getId());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getTopEnemies(com.hack23
     * .cia.model.sweden.ParliamentMember)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMemberVoteCompareResult> getTopEnemies(
            final ParliamentMember parliamentMember) {
        try {
            return createParliamentMemberVoteCompareResultTopBaseCritera().add(
                    hasResult(parliamentMember))
                    .addOrder(Order.asc("result")).setCacheable(true).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getTopEnemiesSameParty
     * (com.hack23.cia.model.sweden.ParliamentMember)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMemberVoteCompareResult> getTopEnemiesSameParty(
            final ParliamentMember parliamentMember) {
        try {
            return createParliamentMemberVoteCompareResultTopBaseCritera().add(
                    isSamePartyHasResult(parliamentMember)).addOrder(
                    Order.asc("result")).setCacheable(true).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getTopFriends(com.hack23
     * .cia.model.sweden.ParliamentMember)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMemberVoteCompareResult> getTopFriends(
            final ParliamentMember parliamentMember) {
        try {
            return createParliamentMemberVoteCompareResultTopBaseCritera().add(
                    hasResult(parliamentMember)).addOrder(Order.desc("result")) //$NON-NLS-1$
                    .setCacheable(true).setMaxResults(10).list();
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#getTopFriendsInSameParty
     * (com.hack23.cia.model.sweden.ParliamentMember)
     */
    @SuppressWarnings("unchecked")
    @Override
    public final List<ParliamentMemberVoteCompareResult> getTopFriendsInSameParty(
            final ParliamentMember parliamentMember) {
        try {
            return createParliamentMemberVoteCompareResultTopBaseCritera().add(
                    isSamePartyHasResult(parliamentMember)).addOrder(
                    Order.desc("result")).setCacheable(true).list(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

    /**
     * Checks for result.
     *
     * @param parliamentMember the parliament member
     * @return the logical expression
     */
    private LogicalExpression hasResult(final ParliamentMember parliamentMember) {
        return Restrictions.and(Restrictions.eq(
                "parliamentMember.id", parliamentMember //$NON-NLS-1$
                        .getId()), Restrictions.ge("result", //$NON-NLS-1$
                ParliamentMemberVoteCompareResult.NO_RESULT));
    }

    /**
     * Checks if is same party.
     *
     * @param parliamentMember the parliament member
     * @return the simple expression
     */
    private SimpleExpression isSameParty(final ParliamentMember parliamentMember) {
        return Property
                .forName("opponent.party").eq(parliamentMember.getParty()); //$NON-NLS-1$
    }

    /**
     * Checks if is same party has result.
     *
     * @param parliamentMember the parliament member
     * @return the logical expression
     */
    private LogicalExpression isSamePartyHasResult(
            final ParliamentMember parliamentMember) {
        return Restrictions.and(isSameParty(parliamentMember),
                hasResult(parliamentMember));
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.ParliamentMemberDAO#saveAll(java.util.Collection
     * )
     */
    @Override
    public final void saveAll(final Collection<ParliamentMember> list) {
        this.getHibernateTemplate().saveOrUpdateAll(list);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.dao.ParliamentMemberDAO#
     * saveParliamentMemberVoteCompareResult(java.util.Collection)
     */
    @Override
    public final void saveParliamentMemberVoteCompareResult(
            final Collection<ParliamentMemberVoteCompareResult> result) {
        getHibernateTemplate().saveOrUpdateAll(result);
    }

}
