/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.dao;

import org.hibernate.HibernateException;
import org.hibernate.criterion.Restrictions;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.sweden.impl.PoliticalParty;

/**
 * The Class PoliticalPartyDAOImpl.
 */
public class PoliticalPartyDAOImpl extends
        GenericHibernateDAO<PoliticalParty, Long> implements
        PoliticalPartyDAO {

    /**
     * Instantiates a new political party dao impl.
     */
    public PoliticalPartyDAOImpl() {
        super(PoliticalParty.class);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.dao.CommiteeReportDAO#findByName(java.lang.String)
     */
    @Transactional(readOnly = true)
    public final PoliticalParty findByName(final String name) {
        try {
            return (PoliticalParty) getSession()
                    .createCriteria(PoliticalParty.class)
                    .add(Restrictions.eq("name", name)).setCacheable(true).uniqueResult(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
    }

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.dao.PoliticalPartyDAO#findByShortCode(java.lang.String)
	 */
	@Transactional(readOnly = true)
	public final PoliticalParty findByShortCode(final String shortCode) {
        try {
            return (PoliticalParty) getSession()
                    .createCriteria(PoliticalParty.class)
                    .add(Restrictions.eq("shortCode", shortCode)).setCacheable(true).uniqueResult(); //$NON-NLS-1$
        } catch (HibernateException hibernateException) {
            throw getHibernateTemplate().convertHibernateAccessException(
                    hibernateException);
        }
	}

}
