/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.admin;

import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.admin.AbstractAdminRequest;
import com.hack23.cia.service.api.common.AbstractServiceRequest;
import com.hack23.cia.service.impl.common.AbstractGenericService;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class AbstractAdminRequestService.
 *
 * @param <REQUEST> the generic type
 */
public abstract class AbstractAdminRequestService<REQUEST extends AbstractAdminRequest>
        extends AbstractGenericService<REQUEST> {

    /** The admin service. */
    private final AdminService adminService;

    /**
     * Instantiates a new abstract admin request service.
     *
     * @param userSessionService the user session service
     * @param adminService the admin service
     */
    public AbstractAdminRequestService(
            final UserSessionService userSessionService,
            final AdminService adminService) {
        super(userSessionService);
        this.adminService = adminService;
    }

    /**
     * Gets the admin service.
     *
     * @return the admin service
     */
    public final AdminService getAdminService() {
        return adminService;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.common.AbstractGenericService#lookupUserSession
     * (com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final UserSession lookupUserSession(
            final AbstractServiceRequest request) {
        UserSession userSession = this.getUserSessionService()
                .loadUserSessionById(request.getUserSessionId());
        return userSession;
    }

}
