/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.admin;

import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.ImageContent;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.model.application.impl.common.LanguageContent.LanguageContentType;
import com.hack23.cia.service.dao.AgencyDAO;
import com.hack23.cia.service.dao.ResourceDAO;
import com.hack23.cia.service.impl.common.ActivityService;
import com.hack23.cia.service.impl.common.ChartService;

/**
 * The Class AdminServiceImpl.
 */
public class AdminServiceImpl implements AdminService {

    /** The activity service. */
    private final ActivityService activityService;

    /** The agency dao. */
    private final AgencyDAO agencyDAO;
    
    /** The agency id. */
    private final long agencyId = 1;
    
    /** The agency name. */
    private final String agencyName = "Default Agency name"; //$NON-NLS-1$

    /** The chart service. */
    private final ChartService chartService;

    /** The resource dao. */
    private final ResourceDAO resourceDAO;

    /** The task service. */
    private final TaskService taskService;

    /**
     * Instantiates a new admin service impl.
     *
     * @param agencyDAO the agency dao
     * @param resourceDAO the resource dao
     * @param taskService the task service
     * @param chartService the chart service
     * @param activityService the activity service
     */
    public AdminServiceImpl(final AgencyDAO agencyDAO,final ResourceDAO resourceDAO,
            final TaskService taskService, final ChartService chartService,
            final ActivityService activityService) {
        super();
        this.agencyDAO = agencyDAO;
        this.resourceDAO = resourceDAO;
        this.taskService = taskService;
        this.chartService = chartService;
        this.activityService = activityService;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.service.impl.admin.AdminService#addAgencyLanguageContent(com.hack23.cia.model.application.impl.common.Agency, com.hack23.cia.model.application.impl.common.Language, java.lang.String, java.lang.String)
     */
    @Override
    public final Agency addAgencyLanguageContent(final Agency agency, final Language language,final String key, final String content) {
        LanguageContent languageContent = new LanguageContent();
        languageContent.setLanguage(language);
        languageContent.setLanguageContentType(LanguageContentType.Agency);
        languageContent.setContent(content);
        languageContent.setContentPropertyName(key);
        languageContent.setDescription("Default description");
        resourceDAO.save(languageContent);
        language.getLanguageContents().add(languageContent);
        agency.getLanguageContent().add(languageContent);
        return agencyDAO.save(agency);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#newLanguage(com.hack23.cia.
     * model.application.Agency)
     */
    @Override
    public final Agency addLanguage(final Agency agency) {
        Agency loadAgency = loadAgency();
        Language language = new Language();
        language.setName("Default"); //$NON-NLS-1$
        language.setShortCode("default"); //$NON-NLS-1$
        language.setActiveByDefault(false);
        language.setUsageOrder(100);
        loadAgency.getLanguages().add(language);
        return agencyDAO.save(loadAgency);
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.service.impl.admin.AdminService#addLanguageContent(com.hack23.cia.model.application.common.Agency, com.hack23.cia.model.application.common.Language)
     */
    @Override
    public final LanguageContent addLanguageContent(final Agency agency, final Language language) {
        LanguageContent languageContent = new LanguageContent();
        languageContent.setLanguage(language);
        languageContent.setLanguageContentType(LanguageContentType.Agency);
        languageContent.setContent("Default value");
        languageContent.setContentPropertyName("default.property.name");
        languageContent.setDescription("Default description");
        agency.getLanguageContent().add(languageContent);
        agencyDAO.save(agency);
        return languageContent;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#newPortal(com.hack23.cia.model
     * .application.Agency)
     */
    @Override
    public final Agency addPortal(final Agency agency) {
        Agency loadAgency = loadAgency();
        Portal portal = new Portal();
        portal.setAgency(loadAgency);
        portal.setName("Default portal"); //$NON-NLS-1$
        portal.setTitleDescription("Default title description"); //$NON-NLS-1$        
        portal.setMatchesUrl("Default url"); //$NON-NLS-1$
        portal.setActiveByDefault(false);
        portal.setUsageOrder(100);
        loadAgency.getPortals().add(portal);
        return agencyDAO.save(loadAgency);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.AdminService#createResponseTimeGraph()
     */
    @Override
    public final ImageContent createResponseTimeGraph() {
    	ImageContent imageContentByFileName = this.resourceDAO.getImageContentByFileName("responseTimeByHour.jpg");
    	resourceDAO.delete(imageContentByFileName);
    	   
        ImageContent createResponseTimeGraph = this.chartService.createResponseTimeGraph(
                this.activityService.getResponseTimeHistory());
        return (ImageContent) resourceDAO.save(createResponseTimeGraph);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#deleteLanguage(com.hack23.cia
     * .model.application.Agency, com.hack23.cia.model.application.Language)
     */
    @Override
    public final Agency deleteLanguage(final Agency agency,
            final Language language) {
        Agency loadAgency = loadAgency();
        Language updatedLanguage = loadAgency.findLanguage(language.getId());
        loadAgency.getLanguages().remove(updatedLanguage);
        
        LanguageContent[] contents = new LanguageContent[updatedLanguage.getLanguageContents().size()];
        contents =updatedLanguage.getLanguageContents().toArray(contents);
        for (LanguageContent languageContent : contents) {
            loadAgency.getLanguageContent().remove(languageContent);
            updatedLanguage.getLanguageContents().remove(languageContent);
            resourceDAO.delete(languageContent);
        }
        
        Agency updatedAgency = agencyDAO.save(loadAgency);        
        resourceDAO.delete(updatedLanguage);
        return updatedAgency;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.service.impl.admin.AdminService#deleteLanguageContent(com.hack23.cia.model.application.common.Agency, com.hack23.cia.model.application.common.LanguageContent)
     */
    @Override
    public final Agency deleteLanguageContent(final Agency agency,
            final LanguageContent languageContent) {
        Agency loadedAgency = loadAgency(agency.getId());
        LanguageContent deleteLanguageContent = loadedAgency.findLanguageContent(languageContent.getId());
        Language language = deleteLanguageContent.getLanguage();
        language.getLanguageContents().remove(deleteLanguageContent);
        deleteLanguageContent.setLanguage(null);
        
        loadedAgency.getLanguageContent().remove(deleteLanguageContent);
        Agency updatedAgency = agencyDAO.save(loadedAgency);
        resourceDAO.save(language);
        resourceDAO.delete(deleteLanguageContent);
        
        return updatedAgency;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#deletePortal(com.hack23.cia
     * .model.application.Portal)
     */
    @Override
    public final Agency deletePortal(final Portal portal) {
        Agency agency = loadAgency();
        Portal deletePortal = agency.getPortalById(portal.getId());
        deletePortal.setAgency(null);
        agency.getPortals().remove(deletePortal);
        
        Agency updatedAgency = agencyDAO.save(agency);
        resourceDAO.delete(deletePortal);
        
        return updatedAgency;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.AdminService#getRecentActionsGraph()
     */
    @Override
    public final ImageContent getRecentActionsGraph() {
    	ImageContent imageContentByFileName = this.resourceDAO.getImageContentByFileName("ActionsByHour.jpg");
    	resourceDAO.delete(imageContentByFileName);
    	
        ImageContent createRecentActionsGraph = this.chartService.createRecentActionsGraph(
                this.activityService.getActionEventHistory());
        return (ImageContent) resourceDAO.save(createRecentActionsGraph);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.InformationService#loadAgency()
     */
    @Override
    public final Agency loadAgency() {
        Agency agency = this.agencyDAO.load(agencyId);
        if (agency == null) {
            agency = new Agency();
            agency.setName(agencyName);
            agencyDAO.save(agency);
        }
        return agency;
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.service.impl.admin.AdminService#loadAgency(java.lang.Long)
     */
    @Override
    public final Agency loadAgency(final Long agencyId) {
        return this.agencyDAO.load(agencyId);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.AdminService#startUpdateJob()
     */
    @Override
    public final void startUpdateJob() {
        this.taskService.execute();
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#updateAgency(com.hack23.cia
     * .model.application.Agency)
     */
    @Override
    public final Agency updateAgency(final Agency agency) {
        Agency loadAgency = loadAgency(agency.getId());

        if (agency != null) {
            loadAgency.setName(agency.getName());
        }

        agencyDAO.save(loadAgency);
        return loadAgency;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#updateLanguage(com.hack23.cia
     * .model.application.Agency, com.hack23.cia.model.application.Language)
     */
    @Override
    public final Agency updateLanguage(final Agency agency,
            final Language language) {
        Agency loadAgency = loadAgency();
        Language updatedLanguage = loadAgency.findLanguage(language.getId());
        updatedLanguage.setName(language.getName());
        updatedLanguage.setShortCode(language.getShortCode());
        updatedLanguage.setActiveByDefault(language.getActiveByDefault());
        updatedLanguage.setUsageOrder(language.getUsageOrder());
    
        return agencyDAO.save(loadAgency);
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.service.impl.admin.AdminService#updateLanguageContent(com.hack23.cia.model.application.common.Agency, com.hack23.cia.model.application.common.LanguageContent)
     */
    @Override
    public final Agency updateLanguageContent(final Agency agency,
            final LanguageContent languageContent) {
        Agency loadedAgency = loadAgency(agency.getId());
        LanguageContent updatedLanguageContent = loadedAgency.findLanguageContent(languageContent.getId());
        updatedLanguageContent.setContent(languageContent.getContent());
        updatedLanguageContent.setDescription(languageContent.getDescription());     
        
        Agency updatedAgency = agencyDAO.save(loadedAgency);
        resourceDAO.save(updatedLanguageContent);
        
        return updatedAgency;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.InformationService#updatePortal(com.hack23.cia
     * .model.application.Portal)
     */
    @Override
    public final Portal updatePortal(final Portal portal) {
        Agency loadAgency = loadAgency();

        Portal updatedPortal = loadAgency.getPortalById(portal.getId());
        updatedPortal.setName(portal.getName());
        updatedPortal.setTitleDescription(portal.getTitleDescription());
        updatedPortal.setMatchesUrl(portal.getMatchesUrl());
        updatedPortal.setActiveByDefault(portal.getActiveByDefault());
        updatedPortal.setUsageOrder(portal.getUsageOrder());
    
        agencyDAO.save(loadAgency);
        return updatedPortal;
    }
}
