/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.admin;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.LanguageContentActionEvent;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.admin.LanguageContentRequest;
import com.hack23.cia.service.api.admin.LanguageContentResponse;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class LanguageContentRequestService.
 */
public class LanguageContentRequestService extends
        AbstractAdminRequestService<LanguageContentRequest> {

    /**
     * Instantiates a new language content request service.
     *
     * @param userSessionService the user session service
     * @param adminService the admin service
     */
    public LanguageContentRequestService(final UserSessionService userSessionService,
            final AdminService adminService) {
        super(userSessionService, adminService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(final LanguageContentRequest request,
            final UserSession userSession) {
        return new LanguageContentActionEvent(new Date(), userSession, request
                .getAgency().getId(), request.getLanguageContent().getId(), request
                .getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return LanguageContentRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final LanguageContentRequest request, final UserSessionDTO userSession) {
        LanguageContentResponse languageResponse = null;

        switch (request.getOperation()) {
        case Update:
            Agency updatedAgency = this.getAdminService().updateLanguageContent(
                    request.getAgency(), request.getLanguageContent());
            LanguageContent updatedLanguageContent = updatedAgency.findLanguageContent(request
                    .getLanguageContent().getId());
            languageResponse = new LanguageContentResponse(userSession, updatedAgency,
                    updatedLanguageContent);
            break;
        case Delete:
            Language language = request.getLanguageContent().getLanguage();
            Agency agency = this.getAdminService().deleteLanguageContent(
                    request.getAgency(), request.getLanguageContent());
            language = agency.findLanguage(language.getId());
            languageResponse = new LanguageContentResponse(userSession, agency,language);
            break;            
        default:
            break;
        }
        return languageResponse;
    }
}
