/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.admin;

import java.util.Date;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.LanguageAgencyActionEvent;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.admin.LanguageRequest;
import com.hack23.cia.service.api.admin.LanguageResponse;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class LanguageRequestService.
 */
public class LanguageRequestService extends
        AbstractAdminRequestService<LanguageRequest> {

    /**
     * Instantiates a new language request service.
     *
     * @param userSessionService the user session service
     * @param adminService the admin service
     */
    public LanguageRequestService(final UserSessionService userSessionService,
            final AdminService adminService) {
        super(userSessionService, adminService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(final LanguageRequest request,
            final UserSession userSession) {
        return new LanguageAgencyActionEvent(new Date(), userSession, request
                .getAgency().getId(), request.getLanguage().getId(), request
                .getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return LanguageRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final LanguageRequest request, final UserSessionDTO userSession) {
        LanguageResponse languageResponse = null;

        switch (request.getOperation()) {
        case Update:
            Agency updatedAgency = this.getAdminService().updateLanguage(
                    request.getAgency(), request.getLanguage());
            Language updatedLanguage = updatedAgency.findLanguage(request
                    .getLanguage().getId());
            languageResponse = new LanguageResponse(userSession, updatedAgency,
                    updatedLanguage);

            break;
        case Delete:
            Agency agency = this.getAdminService().deleteLanguage(
                    request.getAgency(), request.getLanguage());
            languageResponse = new LanguageResponse(userSession, agency);
            break;
        case AddLanguageContent:
            Agency loadAgency = this.getAdminService().loadAgency(request.getAgency().getId());
            Language loadLanguage = loadAgency.findLanguage(request
                    .getLanguage().getId());
            
            LanguageContent languageContent = this.getAdminService().addLanguageContent(
                    loadAgency, loadLanguage);
            
            languageResponse = new LanguageResponse(userSession, loadAgency,languageContent);
            break;
            
        default:
            break;
        }
        return languageResponse;
    }
}
