/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.admin;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.quartz.SchedulerException;
import org.springframework.context.ApplicationContext;

/**
 * The Class LoaderJob.
 */
public class LoaderJob implements Job {

    /** The Constant ADMIN_SERVICE. */
    private static final String ADMIN_SERVICE = "adminService"; //$NON-NLS-1$

    /** The Constant APPLICATION_CONTEXT. */
    private static final String APPLICATION_CONTEXT = "applicationContext"; //$NON-NLS-1$

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory.getLog(LoaderJob.class);

    /*
     * (non-Javadoc)
     * 
     * @see org.quartz.Job#execute(org.quartz.JobExecutionContext)
     */
    @Override
    public final void execute(final JobExecutionContext context)
            throws JobExecutionException {
        AdminService adminService = null;
        try {
            ApplicationContext ctx = (ApplicationContext) context
                    .getScheduler().getContext().get(APPLICATION_CONTEXT);
            adminService = (AdminService) ctx.getBean(ADMIN_SERVICE);
        } catch (SchedulerException e) {
            LOGGER.error("Quartz Scheduling", e); //$NON-NLS-1$
        }

        if (adminService != null) {
            LOGGER.info("Quartz job started"); //$NON-NLS-1$
            adminService.startUpdateJob();
            LOGGER.info("Quartz job completed"); //$NON-NLS-1$
        }
    }
}
