/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.admin;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.model.sweden.impl.Vote;

/**
 * The Interface LoaderService.
 */
public interface LoaderService {

    /**
     * Adds the ballot information.
     *
     * @param ballotId the ballot id
     * @param list the list
     */
    void addBallotInformation(Long ballotId, List<Vote> list);

    /**
     * Adds the committee report information.
     *
     * @param id the id
     * @param decidedDateIfAny the decided date if any
     * @param findVotedballots the find votedballots
     */
    void addCommitteeReportInformation(Long id, Date decidedDateIfAny,
            List<Ballot> findVotedballots);

    /**
     * Adds the if not exist.
     *
     * @param commiteeReport the commitee report
     */
    void addIfNotExist(CommitteeReport commiteeReport);

    /**
     * Adds the if not exist.
     *
     * @param politcalParty the politcal party
     */
	void addIfNotExist(PoliticalParty politcalParty);

    /**
     * Creates the parliament member vote compare results.
     */
    void createParliamentMemberVoteCompareResults();

    /**
     * Delete parliament member vote compare results.
     */
    void deleteParliamentMemberVoteCompareResults();

    /**
     * Generate ballot charts.
     *
     * @param ballotId the ballot id
     */
	void generateBallotCharts(Long ballotId);

    /**
     * Generate committee report charts.
     */
	void generateCommitteeReportCharts();

    /**
     * Generate parliament charts.
     */
	void generateParliamentCharts();

    /**
     * Generate parliament member charts.
     *
     * @param parliamentMemberId the parliament member id
     */
	void generateParliamentMemberCharts(Long parliamentMemberId);

    /**
     * Generate political party charts.
     *
     * @param politicalPartyId the political party id
     */
	void generatePoliticalPartyCharts(Long politicalPartyId);

    /**
     * Gets the all ballots.
     *
     * @return the all ballots
     */
    List<Ballot> getAllBallots();

	/**
	 * Gets the all completed ballotar.
	 *
	 * @return the all completed ballotar
	 */
    List<Ballot> getAllCompletedBallotar();

	/**
	 * Gets the all created ballotar.
	 *
	 * @return the all created ballotar
	 */
    List<Ballot> getAllCreatedBallotar();
	
	/**
	 * Gets the all created committee reports.
	 *
	 * @return the all created committee reports
	 */
    List<CommitteeReport> getAllCreatedCommitteeReports();
	
	/**
	 * Gets the all political parties.
	 *
	 * @return the all political parties
	 */
	List<PoliticalParty> getAllPoliticalParties();
	
	/**
	 * Gets the current list.
	 *
	 * @return the current list
	 */
    List<ParliamentMember> getCurrentList();
	
	/**
	 * Update parliament members english wiki href.
	 *
	 * @param updates the updates
	 */
    void updateParliamentMembersEnglishWikiHref(Map<Long, String> updates);
	
    /**
     * Update parliament members href.
     *
     * @param updates the updates
     */
    void updateParliamentMembersHref(Map<Long, String> updates);
	
	/**
	 * Update parliament members wiki href.
	 *
	 * @param updates the updates
	 */
    void updateParliamentMembersWikiHref(Map<Long, String> updates);
	
}
