/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.agent.sweden;

import gnu.trove.THashMap;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.StringReader;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.core.io.Resource;

import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.RegisterInformation;

/**
 * The Class ParliamentMemberRegisterAgentImpl.
 */
public class ParliamentMemberRegisterAgentImpl implements
        ParliamentMemberRegisterAgent, ApplicationContextAware {

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(ParliamentMemberRegisterAgentImpl.class);

    /** The application context. */
    private ApplicationContext applicationContext;

    /** The current ledamot register. */
    private String currentLedamotRegister = "WEB-INF/Ledamotsregister.mars.2010.xls";

    /** The current ledamot register local. */
    private String currentLedamotRegisterLocal = "src/main/webapp/WEB-INF/Ledamotsregister.mars.2010.xls";

    /** The register information map. */
    private final Map<String, RegisterInformation> registerInformationMap = new THashMap<String, RegisterInformation>();

    /**
     * Instantiates a new parliament member register agent impl.
     *
     * @throws Exception the exception
     */
    public ParliamentMemberRegisterAgentImpl() throws Exception {
        super();
    }

    /**
     * Extract from lines to list.
     *
     * @param str the str
     * @param list the list
     */
    private void extractFromLinesToList(final String str,
            final List<String> list) {
        BufferedReader reader = new BufferedReader(new StringReader(str));
        String line = null;
        try {
            while ((line = reader.readLine()) != null) {

                if (line.length() > 0) {
                    list.add(line);
                }
            }
        } catch (IOException e) {
            LOGGER.warn("Problem parsing line", e);
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.agent.sweden.ParliamentMemberRegisterAgent#init()
     */
    public final void init() throws Exception {
        Resource resource = applicationContext
        .getResource(currentLedamotRegister);

        InputStream resourceAsStream = null;
        try {
            resourceAsStream = new FileInputStream(resource.getFile());
        } catch (Exception e) {
            try {
            resourceAsStream = new FileInputStream(new File(currentLedamotRegisterLocal));
            } catch (Exception e2) {
                LOGGER.warn("Couldn't read register", e2);
            return;
            }
        }

        POIFSFileSystem fs = new POIFSFileSystem(resourceAsStream);
        HSSFWorkbook wb = new HSSFWorkbook(fs);
        HSSFSheet sheet = wb.getSheetAt(0);

        for (int r = 1; r < sheet.getPhysicalNumberOfRows(); r++) {
            HSSFRow row;
            row = sheet.getRow(r);
            if (row != null) {
                HSSFCell cell;
                RegisterInformation registerInformation = new RegisterInformation();

                cell = row.getCell( 0);
                if (cell != null) {
                    registerInformation.setName(cell.getStringCellValue());
                }
                cell = row.getCell( 1);
                if (cell != null) {
                    registerInformation.setElectoralArea(cell
                            .getStringCellValue());
                }
                cell = row.getCell(2);
                if (cell != null) {
                    registerInformation.setParty(cell.getStringCellValue());
                }
                cell = row.getCell( 3);
                if (cell != null) {

                    extractFromLinesToList(cell.getStringCellValue(),
                            registerInformation.getStocks());
                }
                cell = row.getCell(4);
                if (cell != null) {
                    extractFromLinesToList(cell.getStringCellValue(),
                            registerInformation.getHouses());
                }
                cell = row.getCell(5);
                if (cell != null) {
                    extractFromLinesToList(cell.getStringCellValue(),
                            registerInformation.getIncomeActivity());
                }
                cell = row.getCell(6);
                if (cell != null) {
                    extractFromLinesToList(cell.getStringCellValue(),
                            registerInformation.getAgreements());
                }
                cell = row.getCell(7);
                if (cell != null) {
                    extractFromLinesToList(cell.getStringCellValue(),
                            registerInformation.getRoles());
                }
                cell = row.getCell( 8);
                if (cell != null) {
                    extractFromLinesToList(cell.getStringCellValue(),
                            registerInformation.getPublicRoles());
                }

                cell = row.getCell( 9);
                if (cell != null) {
                    extractFromLinesToList(cell.getStringCellValue(),
                            registerInformation.getAllowances());
                }

                cell = row.getCell(10);
                if (cell != null) {
                    registerInformation.setNothingDeclared(cell
                            .getStringCellValue());
                }

                String key = registerInformation.getName().trim()
                        + registerInformation.getParty().trim();
                LOGGER.info("init, added :" + key);
                registerInformationMap.put(key, registerInformation);

            }
        }

    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.agent.sweden.ParliamentMemberRegisterAgent#
     * lookupRegisterInformation(com.hack23.cia.model.sweden.ParliamentMember)
     */
    @Override
    public final RegisterInformation lookupRegisterInformation(
            final ParliamentMember member) {
        LOGGER.info("lookupRegisterInformation: " + member.getName());

        RegisterInformation registerInformation = this.registerInformationMap
                .get(member.getName().trim() + member.getParty().trim());
        LOGGER.info("found : " + registerInformation);
        return registerInformation;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.springframework.context.ApplicationContextAware#setApplicationContext
     * (org.springframework.context.ApplicationContext)
     */
    @Override
    public final void setApplicationContext(final ApplicationContext arg0) {
        this.applicationContext = arg0;
    }
}
