/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.common;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.common.AbstractServiceRequest;
import com.hack23.cia.service.api.common.ServiceRequest;
import com.hack23.cia.service.api.common.ServiceResponse;

/**
 * The Class AbstractGenericService.
 *
 * @param <REQUEST> the generic type
 */
@Transactional(propagation = Propagation.REQUIRED)
public abstract class AbstractGenericService<REQUEST extends AbstractServiceRequest>
        implements BusinessService {
    
    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(AbstractGenericService.class);


    /** The user session service. */
    private final UserSessionService userSessionService;

    /**
     * Instantiates a new abstract generic service.
     *
     * @param userSessionService the user session service
     */
    public AbstractGenericService(final UserSessionService userSessionService) {
        super();
        this.userSessionService = userSessionService;
    }

    /**
     * Creates the action event.
     *
     * @param service the service
     * @param userSession the user session
     * @return the action event
     */
    public abstract ActionEvent createActionEvent(REQUEST service,
            UserSession userSession);

    /**
     * Gets the user session service.
     *
     * @return the user session service
     */
    public final UserSessionService getUserSessionService() {
        return userSessionService;
    }

    /**
     * Handle service request.
     *
     * @param service the service
     * @param userSession the user session
     * @return the service response
     */
    public abstract ServiceResponse handleServiceRequest(REQUEST service,
            UserSessionDTO userSession);

    /**
     * Lookup user session.
     *
     * @param request the request
     * @return the user session
     */
    public abstract UserSession lookupUserSession(AbstractServiceRequest request);

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.common.ServiceHandler#processService(com.hack23
     * .cia.service.api.ServiceRequest)
     */
    @SuppressWarnings("unchecked")
    public final ServiceResponse processService(
            final ServiceRequest serviceRequest) {
        ServiceResponse serviceResponse = null;
        UserSession userSession = lookupUserSession((REQUEST) serviceRequest);
        
        if (userSession != null) {
            ActionEvent actionEvent = createActionEvent((REQUEST) serviceRequest,
                userSession);
            serviceResponse = handleServiceRequest(
                (REQUEST) serviceRequest, new UserSessionDTO(userSession));
            LOGGER.info("ServiceResonse " + serviceResponse.getResult());
            actionEvent.computeExutionTime();
            this.userSessionService.addActionEvent(actionEvent, userSession);
            LOGGER.info("Event logged : " + actionEvent);
        } 
        return serviceResponse;
    }
}
