/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.common;

import java.util.Date;

import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.ApplicationErrorActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.common.AbstractServiceRequest;
import com.hack23.cia.service.api.common.ApplicationErrorRequest;
import com.hack23.cia.service.api.common.ApplicationErrorResponse;
import com.hack23.cia.service.api.common.ServiceResponse;

/**
 * The Class ApplicationErrorRequestService.
 */
@Transactional(propagation = Propagation.REQUIRES_NEW)
public class ApplicationErrorRequestService extends
        AbstractGenericService<ApplicationErrorRequest> {

    /**
     * Instantiates a new application error request service.
     *
     * @param userSessionService the user session service
     */
    public ApplicationErrorRequestService(
            final UserSessionService userSessionService) {
        super(userSessionService);
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(
            final ApplicationErrorRequest request, final UserSession userSession) {
        
        StackTraceElement[] stackTraceElements = request.getStackTraceElements();
        StringBuilder stringBuilder = new StringBuilder();
        
        for (StackTraceElement stackTraceElement : stackTraceElements) {
            stringBuilder.append(stackTraceElement.toString());
            stringBuilder.append("\n");
        }
        
        return new ApplicationErrorActionEvent(new Date(), userSession,stringBuilder.toString(),request.getErrorMessage());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return ApplicationErrorRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final ApplicationErrorRequest request, final UserSessionDTO userSession) {
        ApplicationErrorResponse response = new ApplicationErrorResponse(userSession, "Error Logged");
        return response;
    }
    
    /* (non-Javadoc)
     * @see com.hack23.cia.service.impl.common.AbstractGenericService#lookupUserSession(com.hack23.cia.service.api.common.AbstractServiceRequest)
     */
    @Override
    public final UserSession lookupUserSession(
            final AbstractServiceRequest request) {
        UserSession userSession = null;
        if (request.getUserSessionId() != null) {
        
            userSession = getUserSessionService().loadUserSessionById(
                request.getUserSessionId());
        
        }

        if (userSession == null) {
            userSession = getUserSessionService()
                   .createUserSession("fake error usersession",
                           "fake error usersession",
                           "localhost",
                           "en","useragent");
       }        
        return userSession;
    }


}
