/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.user;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import net.sf.ehcache.Cache;
import net.sf.ehcache.CacheManager;
import net.sf.ehcache.Element;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.ParliamentMemberActionEvent;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.RegisterInformation;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.api.user.ParliamentMemberRequest;
import com.hack23.cia.service.api.user.ParliamentMemberResponse;
import com.hack23.cia.service.impl.common.ParliamentService;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class ParliamentMemberRequestService.
 */
public class ParliamentMemberRequestService extends
        AbstractParliamentRequestService<ParliamentMemberRequest> {

    /** The cache manager. */
    private final CacheManager cacheManager;
	
	/** The cache. */
	private Cache cache;

	/**
	 * Instantiates a new parliament member request service.
	 *
	 * @param userSessionService the user session service
	 * @param parliamentService the parliament service
	 * @param cacheManager the cache manager
	 */
    public ParliamentMemberRequestService(
            final UserSessionService userSessionService,
            final ParliamentService parliamentService,CacheManager cacheManager) {
        super(userSessionService, parliamentService);
		this.cacheManager = cacheManager;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(
            final ParliamentMemberRequest request, final UserSession userSession) {
        return new ParliamentMemberActionEvent(new Date(), userSession, request
                .getParliamentMemberId());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return ParliamentMemberRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final ParliamentMemberRequest request, final UserSessionDTO userSession) {
    	
    	if (cache == null) {    		
    		cache = this.cacheManager.getCache("parliamentMemberRequestCache");
    	}
    	Element element = cache.get(request.getParliamentMemberId());
    	
    	if (element == null) {
	        ParliamentMember parliamentMember = getParliamentService()
	                .getParliamentMember(request.getParliamentMemberId());
	        List<ParliamentMemberVoteCompareResult> friendList = getParliamentService()
	                .getParliamentMemberFriends(parliamentMember);
	        List<ParliamentMemberVoteCompareResult> enemyList = getParliamentService()
	                .getParliamentMemberEnemies(parliamentMember);
	        List<ParliamentMemberVoteCompareResult> friendPartyList = getParliamentService()
	                .getParliamentMemberPartyFriends(parliamentMember);
	        List<ParliamentMemberVoteCompareResult> enemyPartyList = getParliamentService()
	                .getParliamentMemberPartyEnemies(parliamentMember);
	
	        List<Vote> votes = getParliamentService().findLastVotes(
	                parliamentMember.getId());
	
	        RegisterInformation registerInformation = getParliamentService()
	                .lookupRegisterInformation(parliamentMember);
        
	        List<Object> cacheObjects = new ArrayList<Object>();    		
	        cacheObjects.add(parliamentMember);	        
	        cacheObjects.add(friendList);
	        cacheObjects.add(enemyList);	        
    		cacheObjects.add(friendPartyList);
    		cacheObjects.add(enemyPartyList);
    		cacheObjects.add(votes);
    		cacheObjects.add(registerInformation);	        
	        
    		Element cacheElement = new Element(request.getParliamentMemberId(), cacheObjects);
    		cache.put(cacheElement);
    		
	        ParliamentMemberResponse parliamentMemberResponse = new ParliamentMemberResponse(
	        		userSession, parliamentMember, friendList, enemyList,
	        		friendPartyList, enemyPartyList, votes, registerInformation);
	        	        
	        return parliamentMemberResponse;
    	} else {
    		List<Object> cacheObjects = (List<Object>) element.getValue();
    		
    		ParliamentMemberResponse parliamentMemberResponse = new ParliamentMemberResponse(
	        		userSession,(ParliamentMember) cacheObjects.get(0),(List<ParliamentMemberVoteCompareResult> ) cacheObjects.get(1),(List<ParliamentMemberVoteCompareResult> ) cacheObjects.get(2),
	        		(List<ParliamentMemberVoteCompareResult>) cacheObjects.get(3),(List<ParliamentMemberVoteCompareResult> ) cacheObjects.get(4),(List<Vote>) cacheObjects.get(5), (RegisterInformation)cacheObjects.get(6));
	        	        
	        return parliamentMemberResponse;
    	}
    }
}
