/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.service.impl.user;

import java.util.Date;
import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.ActionEvent;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.PartyActionEvent;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.service.api.user.PartyRequest;
import com.hack23.cia.service.api.user.TopListResponse;
import com.hack23.cia.service.impl.common.ParliamentService;
import com.hack23.cia.service.impl.common.UserSessionService;

/**
 * The Class PartyRequestService.
 */
public class PartyRequestService extends
        AbstractParliamentRequestService<PartyRequest> {

    /** The number in top list. */
    private final int numberInTopList;

    /**
     * Instantiates a new party request service.
     *
     * @param userSessionService the user session service
     * @param parliamentService the parliament service
     * @param numberInTopList the number in top list
     */
    public PartyRequestService(final UserSessionService userSessionService,
            final ParliamentService parliamentService, final int numberInTopList) {
        super(userSessionService, parliamentService);
        this.numberInTopList = numberInTopList;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.service.impl.common.AbstractGenericService#createActionEvent
     * (com.hack23.cia.service.api.common.AbstractServiceRequest,
     * com.hack23.cia.model.application.UserSession)
     */
    @Override
    public final ActionEvent createActionEvent(final PartyRequest request,
            final UserSession userSession) {
        return new PartyActionEvent(new Date(), userSession,
                request.getParty(), request.getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.service.common.ServiceHandler#getSupportedService()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedService() {
        return PartyRequest.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.service.common.AbstractGenericServiceHandler#
     * handleServiceRequest(com.hack23.cia.service.api.AbstractServiceRequest)
     */
    @Override
    public final ServiceResponse handleServiceRequest(
            final PartyRequest request, final UserSessionDTO userSession) {
        List<ParliamentMember> members = null;
        
        PoliticalParty politicalParty = getParliamentService().findPoliticalPartyByShortCode(request.getParty());

        switch (request.getOperation()) {
        case TopAbsent:
            members = getParliamentService().getCurrentTopListAbsentInParty(
                    numberInTopList, politicalParty.getShortCode());
            break;
        case TopPresent:
            members = getParliamentService().getCurrentTopListPresentInParty(
                    numberInTopList, politicalParty.getShortCode());
            break;
        case TopWinners:
            members = getParliamentService().getCurrentTopListWinnersInParty(
                    numberInTopList, politicalParty.getShortCode());
            break;
        case TopLosers:
            members = getParliamentService().getCurrentTopListLosersInParty(
                    numberInTopList, politicalParty.getShortCode());
            break;
        case TopLoyals:
            members = getParliamentService().getCurrentTopListLoyalInParty(
                    numberInTopList, politicalParty.getShortCode());
            break;
        case TopRebels:
            members = getParliamentService().getCurrentTopListRebelsInParty(
                    numberInTopList, politicalParty.getShortCode());
            break;
        default:
            break;
        }

        TopListResponse partyResponse = new TopListResponse(userSession,
                members);
        return partyResponse;
    }
}
