/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.action.common;

/**
 * The Class ApplicationErrorAction.
 */
public class ApplicationErrorAction extends AbstractAction {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The error message. */
    private final String errorMessage;

    /** The stack trace elements. */
    private final StackTraceElement[] stackTraceElements;
    
    /**
     * Instantiates a new application error action.
     *
     * @param stackTraceElements the stack trace elements
     * @param errorMessage the error message
     */
    public ApplicationErrorAction(final StackTraceElement[] stackTraceElements,final String errorMessage) {
        super(ActionCategory.Application);
        this.stackTraceElements = stackTraceElements;
        this.errorMessage = errorMessage;
    }


    /**
     * Gets the error message.
     *
     * @return the error message
     */
    public final String getErrorMessage() {
        return errorMessage;
    }

    /**
     * Gets the stack trace elements.
     *
     * @return the stack trace elements
     */
    public final StackTraceElement[] getStackTraceElements() {
        return stackTraceElements;
    }

}
