/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.admin;

import com.hack23.cia.service.api.admin.LanguageContentRequest;
import com.hack23.cia.service.api.admin.LanguageContentResponse;
import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.web.action.admin.LanguageContentAction;
import com.hack23.cia.web.viewfactory.api.admin.LanguageAgencyModelAndView;
import com.hack23.cia.web.viewfactory.api.admin.LanguageContentModelAndView;
import com.hack23.cia.web.viewfactory.api.admin.LanguageAgencyModelAndView.LanguageAgencyViewSpecification;
import com.hack23.cia.web.viewfactory.api.admin.LanguageContentModelAndView.LanguageContentViewSpecification;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;

/**
 * The Class LanguageContentActionHandler.
 */
public class LanguageContentActionHandler
        extends
        AbstractAdminActionHandler<LanguageContentAction, LanguageContentRequest, LanguageContentResponse> {

    /**
     * Instantiates a new language content action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public LanguageContentActionHandler(
            final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final LanguageContentRequest createServiceRequest(
            final LanguageContentAction action) {
        return new LanguageContentRequest(getUserStateService().getUserSessionId(),
                action.getOperation(), action.getAgency(),action.getLanguageContent());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return LanguageContentAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(
            final LanguageContentAction action, final LanguageContentResponse response) {
        ModelAndView modelAndView = null;

        switch (action.getOperation()) {
        case Update:
            modelAndView = new LanguageContentModelAndView(
                    response.getUserSessionDTO(),
                    action,
                    LanguageContentViewSpecification.ConfigureLanguageContentView,
                    response.getAgency(), response.getLanguageContent());
            break;
        case Delete:
            modelAndView = new LanguageAgencyModelAndView(
                    response.getUserSessionDTO(),
                    action,
                    LanguageAgencyViewSpecification.ConfigureAgencyLanguageView,
                    response.getAgency(), response.getLanguage());
            break;
        default:
            break;
        }

        return modelAndView;
    }

}
