/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.admin;

import com.hack23.cia.service.api.admin.MonitorRequest;
import com.hack23.cia.service.api.admin.MonitorResponse;
import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.web.action.admin.MonitorAdminAction;
import com.hack23.cia.web.viewfactory.api.admin.MonitorModelAndView;
import com.hack23.cia.web.viewfactory.api.admin.MonitorModelAndView.MonitorViewSpecification;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;

/**
 * The Class MonitorActionHandler.
 */
public class MonitorActionHandler
        extends
        AbstractAdminActionHandler<MonitorAdminAction, MonitorRequest, MonitorResponse> {

    /**
     * Instantiates a new monitor action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public MonitorActionHandler(final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final MonitorRequest createServiceRequest(
            final MonitorAdminAction action) {
        return new MonitorRequest(getUserStateService().getUserSessionId(),
                action.getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return MonitorAdminAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(
            final MonitorAdminAction action, final MonitorResponse response) {
        ModelAndView modelAndView = null;

        switch (action.getOperation()) {
        case ResponseTime:
            modelAndView = new MonitorModelAndView(response.getUserSessionDTO(),
                    action, MonitorViewSpecification.ResponseTimeView, response
                            .getGraphFile());
            break;
        case RecentActions:
            modelAndView = new MonitorModelAndView(response.getUserSessionDTO(),
                    action, MonitorViewSpecification.RecentActionsView,
                    response.getGraphFile());
            break;
        default:
            break;
        }

        return modelAndView;

    }

}
