/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.admin;

import com.hack23.cia.service.api.admin.PortalRequest;
import com.hack23.cia.service.api.admin.PortalResponse;
import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.web.action.admin.PortalAction;
import com.hack23.cia.web.viewfactory.api.admin.AgencyModelAndView;
import com.hack23.cia.web.viewfactory.api.admin.PortalModelAndView;
import com.hack23.cia.web.viewfactory.api.admin.AgencyModelAndView.AgencyViewSpecification;
import com.hack23.cia.web.viewfactory.api.admin.PortalModelAndView.PortalViewSpecification;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;

/**
 * The Class PortalActionHandler.
 */
public class PortalActionHandler extends
        AbstractAdminActionHandler<PortalAction, PortalRequest, PortalResponse> {

    /**
     * Instantiates a new portal action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public PortalActionHandler(final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final PortalRequest createServiceRequest(final PortalAction action) {
        return new PortalRequest(getUserStateService().getUserSessionId(),
                action.getOperation(), action.getPortal());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return PortalAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(final PortalAction action,
            final PortalResponse response) {
        ModelAndView modelAndView = null;
        switch (action.getOperation()) {
        case Update:
            modelAndView = new PortalModelAndView(response.getUserSessionDTO(),
                    action, PortalViewSpecification.ConfigurePortalView,
                    response.getPortal());
            break;
        case Delete:
            modelAndView = new AgencyModelAndView(response.getUserSessionDTO(),
                    action, AgencyViewSpecification.ConfigureAgencyView,
                    response.getAgency());
            break;
        default:
            break;
        }
        return modelAndView;
    }

}
