/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.application;

import gnu.trove.THashMap;

import java.util.Map;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.application.ApplicationRequest;
import com.hack23.cia.service.api.application.ApplicationResponse;
import com.hack23.cia.web.action.application.ApplicationAction;
import com.hack23.cia.web.controller.common.AbstractGenericHandler;
import com.hack23.cia.web.viewfactory.api.application.ApplicationModelAndView;
import com.hack23.cia.web.viewfactory.api.application.ApplicationModelAndView.ApplicationViewSpecification;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;

/**
 * The Class ApplicationActionHandler.
 */
public class ApplicationActionHandler
        extends
        AbstractGenericHandler<ApplicationAction, ApplicationRequest, ApplicationResponse> {

    /**
     * Instantiates a new application action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public ApplicationActionHandler(
            final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final ApplicationRequest createServiceRequest(
            final ApplicationAction action) {
        return new ApplicationRequest(createUserSettingMap(action.getArgs()));
    }

    /**
     * Creates the user setting map.
     *
     * @param args the args
     * @return the map
     */
    private Map<String, String> createUserSettingMap(final String[] args) {
        Map<String, String> userSetting = new THashMap<String, String>();

        for (String arg : args) {
            String[] split = arg.split("=", 2); //$NON-NLS-1$

            String key = split[0];
            String value = split[1];

            userSetting.put(key, value);
        }
        return userSetting;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return ApplicationAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(
            final ApplicationAction action, final ApplicationResponse response) {
        ApplicationResponse applicationResponse = response;
        return new ApplicationModelAndView(
                applicationResponse.getUserSessionDTO(), action,
                ApplicationViewSpecification.ApplicationView,
                applicationResponse.getAgency(), applicationResponse
                        .getLastDecidedCommiteeReports(),applicationResponse.getPoliticalParties());
    }

}
