/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.common;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.common.ApplicationErrorRequest;
import com.hack23.cia.service.api.common.ApplicationErrorResponse;
import com.hack23.cia.web.action.common.ApplicationErrorAction;
import com.hack23.cia.web.viewfactory.api.common.ErrorMessageModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;
import com.hack23.cia.web.viewfactory.api.common.ErrorMessageModelAndView.ErrorViewSpecification;

/**
 * The Class ApplicationErrorActionHandler.
 */
public class ApplicationErrorActionHandler
        extends
        AbstractGenericHandler<ApplicationErrorAction, ApplicationErrorRequest, ApplicationErrorResponse> {

    /**
     * Instantiates a new application error action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public ApplicationErrorActionHandler(
            final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final ApplicationErrorRequest createServiceRequest(
            final ApplicationErrorAction action) {
        return new ApplicationErrorRequest(getUserStateService().getUserSessionId(),action.getStackTraceElements(),action.getErrorMessage());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return ApplicationErrorAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(
            final ApplicationErrorAction action, final ApplicationErrorResponse response) {
        ApplicationErrorResponse applicationErrorResponse = response;
        return new ErrorMessageModelAndView(response.getUserSessionDTO(), action, ErrorViewSpecification.ErrorMessageView, applicationErrorResponse.getErrorMessage());
    }

}
