/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.controller.user;

import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.user.PartyRequest;
import com.hack23.cia.service.api.user.TopListResponse;
import com.hack23.cia.web.action.user.PartyAction;
import com.hack23.cia.web.viewfactory.api.common.ModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ViewFactoryService;
import com.hack23.cia.web.viewfactory.api.user.ParliamentMemberListModelAndView;
import com.hack23.cia.web.viewfactory.api.user.ParliamentMemberListModelAndView.ParliamentMemberListViewSpecification;

/**
 * The Class PartyActionHandler.
 */
public class PartyActionHandler
        extends
        AbstractTopListActionHandler<PartyAction, PartyRequest, TopListResponse> {

    /**
     * Instantiates a new party action handler.
     *
     * @param viewFactoryService the view factory service
     * @param applicationManager the application manager
     */
    public PartyActionHandler(final ViewFactoryService viewFactoryService,
            final ApplicationManager applicationManager) {
        super(viewFactoryService, applicationManager);
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * createServiceRequest(com.hack23.cia.web.action.common.AbstractAction)
     */
    @Override
    public final PartyRequest createServiceRequest(final PartyAction action) {

        return new PartyRequest(getUserStateService().getUserSessionId(),
                action.getParty(), action.getOperation());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.ActionHandler#getSupportedAction()
     */
    @SuppressWarnings("unchecked")
    @Override
    public final Class getSupportedAction() {
        return PartyAction.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.controller.common.AbstractGenericHandler#
     * handleSuccessResponse(com.hack23.cia.web.action.common.AbstractAction,
     * com.hack23.cia.service.api.common.AbstractServiceResponse)
     */
    @Override
    public final ModelAndView handleSuccessResponse(final PartyAction action,
            final TopListResponse response) {
        ModelAndView modelAndView = null;

        switch (action.getOperation()) {
        case TopAbsent:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopAbsentInPartyView,
                    response.getParliamentMembers());
            break;
        case TopPresent:
            modelAndView = new ParliamentMemberListModelAndView(
                    response.getUserSessionDTO(),
                    action,
                    ParliamentMemberListViewSpecification.TopPresentInPartyView,
                    response.getParliamentMembers());
            break;
        case TopWinners:
            modelAndView = new ParliamentMemberListModelAndView(
                    response.getUserSessionDTO(),
                    action,
                    ParliamentMemberListViewSpecification.TopWinnersInPartyView,
                    response.getParliamentMembers());
            break;
        case TopLosers:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopLosersInPartyView,
                    response.getParliamentMembers());
            break;
        case TopRebels:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopRebelsInPartyView,
                    response.getParliamentMembers());
            break;
        case TopLoyals:
            modelAndView = new ParliamentMemberListModelAndView(response
                    .getUserSessionDTO(), action,
                    ParliamentMemberListViewSpecification.TopLoyalsInPartyView,
                    response.getParliamentMembers());
            break;
        default:
            break;
        }
        return modelAndView;

    }

}
