/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.admin;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class AgencyModelAndView.
 */
public class AgencyModelAndView extends AbstractAgencyModelAndView {

    /**
     * The Enum AgencyViewSpecification.
     */
    public enum AgencyViewSpecification {

        /** The Configure agency view. */
        ConfigureAgencyView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The agency view specification. */
    private final AgencyViewSpecification agencyViewSpecification;

    /**
     * Instantiates a new agency model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param agencyViewSpecification the agency view specification
     * @param agency the agency
     */
    public AgencyModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final AgencyViewSpecification agencyViewSpecification,
            final Agency agency) {
        super(userSessionDTO, controllerAction, agency);
        this.agencyViewSpecification = agencyViewSpecification;
    }

    /**
     * Gets the agency view specification.
     *
     * @return the agency view specification
     */
    public final AgencyViewSpecification getAgencyViewSpecification() {
        return agencyViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return agencyViewSpecification.toString();
    }

}
