/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.admin;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class LanguageAgencyModelAndView.
 */
public class LanguageAgencyModelAndView extends AbstractAgencyModelAndView {

    /**
     * The Enum LanguageAgencyViewSpecification.
     */
    public enum LanguageAgencyViewSpecification {

        /** The Configure agency language view. */
        ConfigureAgencyLanguageView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The language. */
    private final Language language;

    /** The language agency view specification. */
    private final LanguageAgencyViewSpecification languageAgencyViewSpecification;

    /**
     * Instantiates a new language agency model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param languageAgencyViewSpecification the language agency view specification
     * @param agency the agency
     * @param language the language
     */
    public LanguageAgencyModelAndView(
            final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final LanguageAgencyViewSpecification languageAgencyViewSpecification,
            final Agency agency, final Language language) {
        super(userSessionDTO, controllerAction, agency);
        this.languageAgencyViewSpecification = languageAgencyViewSpecification;
        this.language = language;
    }

    /**
     * Gets the language.
     *
     * @return the language
     */
    public final Language getLanguage() {
        return language;
    }

    /**
     * Gets the language agency view specification.
     *
     * @return the language agency view specification
     */
    public final LanguageAgencyViewSpecification getLanguageAgencyViewSpecification() {
        return languageAgencyViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return languageAgencyViewSpecification.toString();
    }

}
