/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.admin;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class LanguageContentModelAndView.
 */
public class LanguageContentModelAndView extends AbstractAgencyModelAndView {

    /**
     * The Enum LanguageContentViewSpecification.
     */
    public enum LanguageContentViewSpecification {

        /** The Configure language content view. */
        ConfigureLanguageContentView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The language content. */
    private final LanguageContent languageContent;

    /** The language content view specification. */
    private final LanguageContentViewSpecification languageContentViewSpecification;

    /**
     * Instantiates a new language content model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param languageContentViewSpecification the language content view specification
     * @param agency the agency
     * @param languageContent the language content
     */
    public LanguageContentModelAndView(
            final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final LanguageContentViewSpecification languageContentViewSpecification,
            final Agency agency, final LanguageContent languageContent) {
        super(userSessionDTO, controllerAction, agency);
        this.languageContentViewSpecification = languageContentViewSpecification;
        this.languageContent = languageContent;
    }

    /**
     * Gets the language content.
     *
     * @return the language content
     */
    public final LanguageContent getLanguageContent() {
        return languageContent;
    }

    /**
     * Gets the language content view specification.
     *
     * @return the language content view specification
     */
    public final LanguageContentViewSpecification getLanguageContentViewSpecification() {
        return languageContentViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return languageContentViewSpecification.toString();
    }

}
