/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.admin;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class PortalModelAndView.
 */
public class PortalModelAndView extends AbstractConfigurationModelAndView {

    /**
     * The Enum PortalViewSpecification.
     */
    public enum PortalViewSpecification {

        /** The Configure portal view. */
        ConfigurePortalView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The portal. */
    private final Portal portal;

    /** The portal view specification. */
    private final PortalViewSpecification portalViewSpecification;

    /**
     * Instantiates a new portal model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param portalViewSpecification the portal view specification
     * @param portal the portal
     */
    public PortalModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final PortalViewSpecification portalViewSpecification,
            final Portal portal) {
        super(userSessionDTO, controllerAction);
        this.portalViewSpecification = portalViewSpecification;
        this.portal = portal;
    }

    /**
     * Gets the portal.
     *
     * @return the portal
     */
    public final Portal getPortal() {
        return portal;
    }

    /**
     * Gets the portal view specification.
     *
     * @return the portal view specification
     */
    public final PortalViewSpecification getPortalViewSpecification() {
        return portalViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return portalViewSpecification.toString();
    }
}
