/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.common;

import java.io.Serializable;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class AbstractModelAndView.
 */
public abstract class AbstractModelAndView implements ModelAndView,
        Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The controller action. */
    private final ControllerAction controllerAction;

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;
   
    /**
     * Instantiates a new abstract model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     */
    public AbstractModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction) {
        super();
        this.userSessionDTO = userSessionDTO;
        this.controllerAction = controllerAction;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.web.controller.viewFactory.ModelAndView#getControllerAction
     * ()
     */
    public final ControllerAction getControllerAction() {
        return controllerAction;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.hack23.cia.web.controller.viewfactory.api.ModelAndView#getUser()
     */
    public final UserSessionDTO getUserSessionDTO() {
        return userSessionDTO;
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * com.hack23.cia.web.controller.viewFactory.ModelAndView#getViewSpecification
     * ()
     */
    @Override
    public abstract String getViewSpecificationDescription();
}
