/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.common;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class ErrorMessageModelAndView.
 */
public class ErrorMessageModelAndView extends AbstractModelAndView {

    /**
     * The Enum ErrorViewSpecification.
     */
    public enum ErrorViewSpecification {

        /** The Error message view. */
        ErrorMessageView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The error message. */
    private final String errorMessage;

    /** The error view specification. */
    private final ErrorViewSpecification errorViewSpecification;

    /**
     * Instantiates a new error message model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param errorViewSpecification the error view specification
     * @param errorMessage the error message
     */
    public ErrorMessageModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final ErrorViewSpecification errorViewSpecification,
            final String errorMessage) {
        super(userSessionDTO, controllerAction);
        this.errorViewSpecification = errorViewSpecification;
        this.errorMessage = errorMessage;
    }

    /**
     * Gets the error message.
     *
     * @return the error message
     */
    public final String getErrorMessage() {
        return errorMessage;
    }

    /**
     * Gets the error view specification.
     *
     * @return the error view specification
     */
    public final ErrorViewSpecification getErrorViewSpecification() {
        return errorViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return errorViewSpecification.toString();
    }
}
