/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.user;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class CommitteeReportModelAndView.
 */
public class CommitteeReportModelAndView extends AbstractParliamentModelAndView {

    /**
     * The Enum CommitteeReportViewSpecification.
     */
    public enum CommitteeReportViewSpecification {

        /** The Committee report view. */
        CommitteeReportView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The committee report. */
    private final CommitteeReport committeeReport;

    /** The committee report view specification. */
    private final CommitteeReportViewSpecification committeeReportViewSpecification;

    /**
     * Instantiates a new committee report model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param committeeReportViewSpecification the committee report view specification
     * @param committeeReport the committee report
     */
    public CommitteeReportModelAndView(
            final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final CommitteeReportViewSpecification committeeReportViewSpecification,
            final CommitteeReport committeeReport) {
        super(userSessionDTO, controllerAction);
        this.committeeReportViewSpecification = committeeReportViewSpecification;
        this.committeeReport = committeeReport;
    }

    /**
     * Gets the committee report.
     *
     * @return the committee report
     */
    public final CommitteeReport getCommitteeReport() {
        return committeeReport;
    }

    /**
     * Gets the committee report view specification.
     *
     * @return the committee report view specification
     */
    public final CommitteeReportViewSpecification getCommitteeReportViewSpecification() {
        return committeeReportViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return committeeReportViewSpecification.toString();
    }

}
