/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.user;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class UrlModelAndView.
 */
public class UrlModelAndView extends AbstractUserModelAndView {

    /**
     * The Enum UrlViewSpecification.
     */
    public enum UrlViewSpecification {

        /** The Url view. */
        UrlView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The title. */
    private final String title;

    /** The url. */
    private final String url;

    /** The url view specification. */
    private final UrlViewSpecification urlViewSpecification;

    /**
     * Instantiates a new url model and view.
     *
     * @param userSessionDTO the user session dto
     * @param controllerAction the controller action
     * @param urlViewSpecification the url view specification
     * @param title the title
     * @param url the url
     */
    public UrlModelAndView(final UserSessionDTO userSessionDTO,
            final ControllerAction controllerAction,
            final UrlViewSpecification urlViewSpecification,
            final String title, final String url) {
        super(userSessionDTO, controllerAction);
        this.urlViewSpecification = urlViewSpecification;
        this.title = title;
        this.url = url;
    }

    /**
     * Gets the title.
     *
     * @return the title
     */
    public final String getTitle() {
        return title;
    }

    /**
     * Gets the url.
     *
     * @return the url
     */
    public final String getUrl() {
        return url;
    }

    /**
     * Gets the url view specification.
     *
     * @return the url view specification
     */
    public final UrlViewSpecification getUrlViewSpecification() {
        return urlViewSpecification;
    }

    /*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return urlViewSpecification.toString();
    }

}
