/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.api.user;

import java.util.List;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.web.action.common.ControllerAction;

/**
 * The Class UserModelAndView.
 */
public class UserModelAndView extends AbstractUserModelAndView {

    /**
     * The Enum UserViewSpecification.
     */
    public enum UserViewSpecification {

        /** The Login view. */
		 LoginView,

        /** The Logout view. */
        LogoutView,

        /** The User history view. */
        UserHistoryView,

        /** The User home view. */
        UserHomeView, 
 
 /** The Welcome page view. */
WelcomePageView
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The political parties. */
	private final List<PoliticalParty> politicalParties;

	/** The user view specification. */
    private final UserViewSpecification userViewSpecification;
	
    /**
     * Instantiates a new user model and view.
     *
     * @param userSessionDTO the user session dto
     * @param politicalParties the political parties
     * @param controllerAction the controller action
     * @param userViewSpecification the user view specification
     */
    public UserModelAndView(final UserSessionDTO userSessionDTO,final List<PoliticalParty> politicalParties,
            final ControllerAction controllerAction,
            final UserViewSpecification userViewSpecification) {
        super(userSessionDTO, controllerAction);
		this.politicalParties = politicalParties;
        this.userViewSpecification = userViewSpecification;
    }

    /**
     * Gets the political parties.
     *
     * @return the political parties
     */
	public final List<PoliticalParty> getPoliticalParties() {
		return politicalParties;
	}

    /**
     * Gets the user view specification.
     *
     * @return the user view specification
     */
    public final UserViewSpecification getUserViewSpecification() {
        return userViewSpecification;
    }

	/*
     * (non-Javadoc)
     * 
     * @seecom.hack23.cia.web.viewfactory.api.common.AbstractModelAndView#
     * getViewSpecificationDescription()
     */
    @Override
    public final String getViewSpecificationDescription() {
        return userViewSpecification.toString();
    }

}
