/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.viewfactory.impl.user;

import java.util.List;

import thinwire.ui.Component;
import thinwire.ui.Menu;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.MonitorActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.User;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.application.impl.user.AbstractTopListActionEvent;
import com.hack23.cia.model.application.impl.user.UserAccountActionEvent;
import com.hack23.cia.model.application.impl.user.UserActionEvent;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.web.action.admin.ConfigureAgencyAction;
import com.hack23.cia.web.action.admin.MonitorAdminAction;
import com.hack23.cia.web.action.admin.TaskAction;
import com.hack23.cia.web.action.user.CommitteeReportsAction;
import com.hack23.cia.web.action.user.PartyAction;
import com.hack23.cia.web.action.user.TopListAction;
import com.hack23.cia.web.action.user.UserAccountAction;
import com.hack23.cia.web.action.user.UserAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class MenuFactoryImpl.
 */
public class MenuFactoryImpl implements MenuFactory {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.hack23.cia.web.controller.viewFactory.MenuFactory#createApplicationMenu
	 * (com.hack23.cia.model.application.User, int)
	 */
	public final Menu createApplicationMenu(
			final UserSessionDTO userSessionDTO,
			final List<PoliticalParty> politicalParties, final int topNumber) {
		UserSession userSession = userSessionDTO.getUserSession();
		User user = userSession.getUser();
		String portalName = userSession.getPortal().getName();
		Menu menu = new Menu();

		Menu.Item appItem = new Menu.Item(portalName);
		menu.getRootItem().getChildren().add(appItem);

		if (user.getUserRole().equals(User.UserRole.ANYNOMOUS)) {
			Menu.Item loginItem = new Menu.Item(userSessionDTO
					.getLanguageResource(Agency.LanguageContentKey.LOGIN));
			loginItem.setUserObject(new UserAccountAction(
					UserAccountActionEvent.Operation.Login));
			appItem.getChildren().add(loginItem);
		} else if (user.getUserRole().equals(User.UserRole.USER)
				|| user.getUserRole().equals(User.UserRole.ADMIN)
				|| user.getUserRole().equals(User.UserRole.VIP)) {
			Menu.Item logoutItem = new Menu.Item(userSessionDTO
					.getLanguageResource(Agency.LanguageContentKey.LOGOUT));
			logoutItem.setUserObject(new UserAccountAction(
					UserAccountActionEvent.Operation.Logout));
			appItem.getChildren().add(logoutItem);
		}

		if (user.getUserRole().equals(User.UserRole.ADMIN)) {
			Menu.Item adminMenuItem = new Menu.Item(userSessionDTO
					.getLanguageResource(Agency.LanguageContentKey.ADMIN_MENU));
			menu.getRootItem().getChildren().add(adminMenuItem);

			Menu.Item startUpdateJobItem = new Menu.Item(
					userSessionDTO
							.getLanguageResource(Agency.LanguageContentKey.START_UPDATE_JOB));
			startUpdateJobItem.setUserObject(new TaskAction());
			adminMenuItem.getChildren().add(startUpdateJobItem);

			Menu.Item showResponseTimeItem = new Menu.Item(
					userSessionDTO
							.getLanguageResource(Agency.LanguageContentKey.SHOW_RESPONSE_TIME));
			showResponseTimeItem.setUserObject(new MonitorAdminAction(
					MonitorActionEvent.Operation.ResponseTime));
			adminMenuItem.getChildren().add(showResponseTimeItem);

			Menu.Item showRecentActionsItem = new Menu.Item(
					userSessionDTO
							.getLanguageResource(Agency.LanguageContentKey.SHOW_RECENT_ACTIONS));
			showRecentActionsItem.setUserObject(new MonitorAdminAction(
					MonitorActionEvent.Operation.RecentActions));
			adminMenuItem.getChildren().add(showRecentActionsItem);

			Menu.Item showTreeViewItem = new Menu.Item(
					userSessionDTO
							.getLanguageResource(Agency.LanguageContentKey.COMMITEE_REPORT));
			showTreeViewItem.setUserObject(new CommitteeReportsAction());
			adminMenuItem.getChildren().add(showTreeViewItem);

			Menu.Item configureAgencyViewItem = new Menu.Item(
					userSessionDTO
							.getLanguageResource(Agency.LanguageContentKey.CONFIGURE_AGENCY));
			configureAgencyViewItem.setUserObject(new ConfigureAgencyAction());
			adminMenuItem.getChildren().add(configureAgencyViewItem);
		}

		// Common
		Menu.Item parliamentMenuItem = new Menu.Item(
				userSessionDTO
						.getLanguageResource(Agency.LanguageContentKey.SWEDISH_PARLIAMENT_MENU));
		menu.getRootItem().getChildren().add(parliamentMenuItem);

		if (politicalParties != null) {
			createTopListMenuItem(
					userSessionDTO,
					parliamentMenuItem,
					politicalParties,
					topNumber,
					AbstractTopListActionEvent.Operation.TopRebels,
					userSessionDTO
					.getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_REBELS));
			createTopListMenuItem(
					userSessionDTO,
					parliamentMenuItem,
					politicalParties,
					topNumber,
					AbstractTopListActionEvent.Operation.TopLoyals,
					userSessionDTO
					.getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_LOYAL));

			createTopListMenuItem(
					userSessionDTO,
					parliamentMenuItem,
					politicalParties,
					topNumber,
					AbstractTopListActionEvent.Operation.TopWinners,
					userSessionDTO
							.getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_WINNERS));
			createTopListMenuItem(
					userSessionDTO,
					parliamentMenuItem,
					politicalParties,
					topNumber,
					AbstractTopListActionEvent.Operation.TopLosers,
					userSessionDTO
							.getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_LOSERS));

			createTopListMenuItem(
					userSessionDTO,
					parliamentMenuItem,
					politicalParties,
					topNumber,
					AbstractTopListActionEvent.Operation.TopAbsent,
					userSessionDTO
					.getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_ABSENCE));
			createTopListMenuItem(
					userSessionDTO,
					parliamentMenuItem,
					politicalParties,
					topNumber,
					AbstractTopListActionEvent.Operation.TopPresent,
					userSessionDTO
					.getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_PRESENCE));			
		}

		Menu.Item historyMenuItem = new Menu.Item(userSessionDTO
				.getLanguageResource(Agency.LanguageContentKey.USER_HISTORY));
		menu.getRootItem().getChildren().add(historyMenuItem);

		Menu.Item showUserHistoryItem = new Menu.Item(
				userSessionDTO
						.getLanguageResource(Agency.LanguageContentKey.SHOW_USER_HISTORY));
		showUserHistoryItem.setUserObject(new UserAction(
				UserActionEvent.Operation.UserHistory));
		historyMenuItem.getChildren().add(showUserHistoryItem);

		menu.addActionListener(Component.ACTION_CLICK, BeanLocator
				.getApplicationActionListener());
		return menu;
	}

	/**
	 * Creates the top list menu item.
	 *
	 * @param userSessionDTO the user session dto
	 * @param parliamentMenuItem the parliament menu item
	 * @param politicalParties the political parties
	 * @param topNumber the top number
	 * @param operation the operation
	 * @param menuTitle the menu title
	 */
	private void createTopListMenuItem(final UserSessionDTO userSessionDTO,
			final Menu.Item parliamentMenuItem,
			final List<PoliticalParty> politicalParties, final int topNumber,
			final AbstractTopListActionEvent.Operation operation,
			final String menuTitle) {
		Menu.Item absenceItem = new Menu.Item(menuTitle);
		parliamentMenuItem.getChildren().add(absenceItem);

		Menu.Item showTopSlackerItem = new Menu.Item(userSessionDTO
				.getLanguageResource(Agency.LanguageContentKey.SHOW_TOP)
				+ " " + topNumber); //$NON-NLS-1$
		showTopSlackerItem.setUserObject(new TopListAction(operation));
		absenceItem.getChildren().add(showTopSlackerItem);

		Menu.Item partyItem = new Menu.Item(
				userSessionDTO
						.getLanguageResource(Agency.LanguageContentKey.SHOW_TOP)
						+ " " //$NON-NLS-1$
						+ topNumber
						+ " " //$NON-NLS-1$
						+ userSessionDTO
								.getLanguageResource(Agency.LanguageContentKey.PER_PARTY));
		absenceItem.getChildren().add(partyItem);

		for (PoliticalParty politicalParty : politicalParties) {
			Menu.Item partyMenuItem = new Menu.Item(politicalParty.getName());
			partyMenuItem.setUserObject(new PartyAction(operation,
					politicalParty.getShortCode()));
			partyItem.getChildren().add(partyMenuItem);
		}
	}
}
