/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.admin;

import thinwire.ui.Button;
import thinwire.ui.GridBox;
import thinwire.ui.Label;
import thinwire.ui.TabSheet;
import thinwire.ui.TextField;
import thinwire.ui.event.ActionEvent;
import thinwire.ui.event.ActionListener;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.LanguageAgencyActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.web.action.admin.LanguageAgencyAction;
import com.hack23.cia.web.common.BeanLocator;
import com.hack23.cia.web.views.components.gridboxes.LanguageContentGridBox;

/**
 * The Class ConfigureLanguagePanel.
 */
public class ConfigureLanguagePanel extends AbstractAdminPanel {

    /** The active by default field. */
    private final TextField activeByDefaultField = new TextField();


    /** The cancel language action listener. */
    private final ActionListener cancelLanguageActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            languageNameField.setText(language.getName());
            languageShortCodeField.setText(language.getShortCode());
            activeByDefaultField.setText("" + language.getActiveByDefault());
            usageOrderField.setText("" +language.getUsageOrder());
        }
    };


    /** The delete language action listener. */
    private final ActionListener deleteLanguageActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            ((Button) ev.getSource()).setUserObject(new LanguageAgencyAction(
                    LanguageAgencyActionEvent.Operation.Delete, getAgency(),
                    language));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /** The language. */
    private Language language;

    /** The language name field. */
    private final TextField languageNameField = new TextField();

    /** The language short code field. */
    private final TextField languageShortCodeField = new TextField();

    /** The ok language action listener. */
    private final ActionListener okLanguageActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            language.setName(languageNameField.getText());
            language.setShortCode(languageShortCodeField.getText());
            language.setUsageOrder(Integer.valueOf(usageOrderField.getText()));
            language.setActiveByDefault(Boolean.valueOf(activeByDefaultField.getText()));
            ((Button) ev.getSource()).setUserObject(new LanguageAgencyAction(
                    LanguageAgencyActionEvent.Operation.Update, getAgency(),
                    language));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };


    /** The usage order field. */
    private final TextField usageOrderField = new TextField();

    /**
     * Instantiates a new configure language panel.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     * @param language the language
     */
    public ConfigureLanguagePanel(final UserSessionDTO userSessionDTO,final Agency agency, final Language language) {
        super(userSessionDTO,agency);
        this.language = new Language();
        this.language.setId(language.getId());
        this.language.setShortCode(language.getShortCode());
        this.language.setName(language.getName());
        this.language.setActiveByDefault(language.getActiveByDefault());
        this.language.setUsageOrder(language.getUsageOrder());
        TabSheet gridBoxTabSheet = createLanguageTabSheet(agency,language);
        getTabFolder().getChildren().add(gridBoxTabSheet);
        getTabFolder().setCurrentIndex(1);

    }

    /**
     * Creates the language tab sheet.
     *
     * @param agency the agency
     * @param language the language
     * @return the tab sheet
     */
    private TabSheet createLanguageTabSheet(final Agency agency,final Language language) {
        TabSheet tabSheet = new TabSheet();
        tabSheet.setText(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.CONFIGURE_LANGUAGE));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0, 0, 0 }, // Column
                // Widths
                { 0, 0, 0, 0, 0,0,0,0,0,0 } }, // Row Heights
                10, // Margin around edge of container
                5));

        final Label nameLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.NAME));
        nameLabel.setLimit("0,0"); //$NON-NLS-1$
        tabSheet.getChildren().add(nameLabel);

        languageNameField.setLimit("1,0,2,1"); //$NON-NLS-1$
        languageNameField.setText(language.getName());
        tabSheet.getChildren().add(languageNameField);

        final Label languageShortCodeLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.LANGUAGE_SHORTCODE));
        languageShortCodeLabel.setLimit("0,1"); //$NON-NLS-1$
        tabSheet.getChildren().add(languageShortCodeLabel);

        languageShortCodeField.setLimit("1,1,2,1"); //$NON-NLS-1$
        languageShortCodeField.setText(language.getShortCode());
        tabSheet.getChildren().add(languageShortCodeField);
        
        final Label activeByDefaultLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.ACTIVE_BY_DEFAULT));
        activeByDefaultLabel.setLimit("0,2"); //$NON-NLS-1$
        tabSheet.getChildren().add(activeByDefaultLabel);

        activeByDefaultField.setLimit("1,2,2,1"); //$NON-NLS-1$
        activeByDefaultField.setText("" + language.getActiveByDefault());
        tabSheet.getChildren().add(activeByDefaultField);

        final Label usageOrderLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.USAGE_ORDER));
        usageOrderLabel.setLimit("0,3"); //$NON-NLS-1$
        tabSheet.getChildren().add(usageOrderLabel);

        usageOrderField.setLimit("1,3,2,1"); //$NON-NLS-1$
        usageOrderField.setText("" + language.getUsageOrder());
        tabSheet.getChildren().add(usageOrderField);
        
        GridBox portalGridBox = new LanguageContentGridBox(getUserSessionDTO(),agency,agency.getLanguageContentByLanguage(language));
        portalGridBox.setLimit("0,4,3,3"); //$NON-NLS-1$
        tabSheet.getChildren().add(portalGridBox);
        
        
        final Button deleteButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_DELETE));
        deleteButton.setLimit("0,7"); //$NON-NLS-1$
        deleteButton.addActionListener(ACTION_CLICK,
                deleteLanguageActionListener);
        tabSheet.getChildren().add(deleteButton);

        final Button cancelButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_CANCEL));
        cancelButton.setLimit("1,7"); //$NON-NLS-1$
        cancelButton.addActionListener(ACTION_CLICK,
                cancelLanguageActionListener);
        tabSheet.getChildren().add(cancelButton);

        final Button okButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_OK));
        okButton.setLimit("2,7"); //$NON-NLS-1$
        okButton.addActionListener(ACTION_CLICK, okLanguageActionListener);
        tabSheet.getChildren().add(okButton);
        return tabSheet;
    }

}
