/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.admin;

import thinwire.ui.Button;
import thinwire.ui.Label;
import thinwire.ui.TabSheet;
import thinwire.ui.TextField;
import thinwire.ui.event.ActionEvent;
import thinwire.ui.event.ActionListener;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.admin.PortalActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.web.action.admin.PortalAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class ConfigurePortalPanel.
 */
public class ConfigurePortalPanel extends AbstractAdminPanel {

    /** The active by default field. */
    private final TextField activeByDefaultField = new TextField();

    /** The cancel portal action listener. */
    private final ActionListener cancelPortalActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            portalNameField.setText(portal.getName());
            portalTitleDescription.setText(portal.getTitleDescription());
            portalMatchesUrlField.setText(portal.getName());
            activeByDefaultField.setText("" + portal.getActiveByDefault());
            usageOrderField.setText("" +portal.getUsageOrder());
        }
    };

    /** The delete portal action listener. */
    private final ActionListener deletePortalActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            ((Button) ev.getSource()).setUserObject(new PortalAction(
                    PortalActionEvent.Operation.Delete, portal));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /** The ok portal action listener. */
    private final ActionListener okPortalActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            portal.setName(portalNameField.getText());
            portal.setTitleDescription(portalTitleDescription.getText());
            portal.setMatchesUrl(portalMatchesUrlField.getText());
            portal.setUsageOrder(Integer.valueOf(usageOrderField.getText()));
            portal.setActiveByDefault(Boolean.valueOf(activeByDefaultField.getText()));
            
            ((Button) ev.getSource()).setUserObject(new PortalAction(
                    PortalActionEvent.Operation.Update, portal));
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /** The portal. */
    private Portal portal;

    /** The portal matches url field. */
    private final TextField portalMatchesUrlField = new TextField();

    /** The portal name field. */
    private final TextField portalNameField = new TextField();
    
    /** The portal title description. */
    private final TextField portalTitleDescription = new TextField();

    /** The usage order field. */
    private final TextField usageOrderField = new TextField();


    /**
     * Instantiates a new configure portal panel.
     *
     * @param userSessionDTO the user session dto
     * @param agency the agency
     * @param portal the portal
     */
    public ConfigurePortalPanel(final UserSessionDTO userSessionDTO,final Agency agency, final Portal portal) {
        super(userSessionDTO,agency);
        this.portal = new Portal();
        this.portal.setAgency(agency);
        this.portal.setName(portal.getName());
        this.portal.setTitleDescription(portal.getTitleDescription());
        this.portal.setMatchesUrl(portal.getMatchesUrl());
        this.portal.setId(portal.getId());
        this.portal.setActiveByDefault(portal.getActiveByDefault());
        this.portal.setUsageOrder(portal.getUsageOrder());

        TabSheet gridBoxTabSheet = createPortalTabSheet(portal);
        getTabFolder().getChildren().add(gridBoxTabSheet);
        getTabFolder().setCurrentIndex(1);
    }


    /**
     * Creates the portal tab sheet.
     *
     * @param portal the portal
     * @return the tab sheet
     */
    private TabSheet createPortalTabSheet(final Portal portal) {
        TabSheet tabSheet = new TabSheet();
        tabSheet.setText(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.CONFIGURE_PORTAL));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0, 0, 0 }, // Column
                // Widths
                { 0, 0, 0, 0, 0,0,0 } }, // Row Heights
                10, // Margin around edge of container
                5));

        final Label nameLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.NAME));
        nameLabel.setLimit("0,0"); //$NON-NLS-1$
        tabSheet.getChildren().add(nameLabel);

        portalNameField.setLimit("1,0,2,1"); //$NON-NLS-1$
        portalNameField.setText(portal.getName());
        tabSheet.getChildren().add(portalNameField);

        final Label titleDescriptionLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.INFORMATION));
        titleDescriptionLabel.setLimit("0,1"); //$NON-NLS-1$
        tabSheet.getChildren().add(titleDescriptionLabel);

        portalTitleDescription.setLimit("1,1,2,1"); //$NON-NLS-1$
        portalTitleDescription.setText(portal.getTitleDescription());
        tabSheet.getChildren().add(portalTitleDescription);

        final Label matchesUrlLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.MATCHES_URL));
        matchesUrlLabel.setLimit("0,2"); //$NON-NLS-1$
        tabSheet.getChildren().add(matchesUrlLabel);

        portalMatchesUrlField.setLimit("1,2,2,1"); //$NON-NLS-1$
        portalMatchesUrlField.setText(portal.getMatchesUrl());
        tabSheet.getChildren().add(portalMatchesUrlField);

        
        final Label activeByDefaultLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.ACTIVE_BY_DEFAULT));
        activeByDefaultLabel.setLimit("0,3"); //$NON-NLS-1$
        tabSheet.getChildren().add(activeByDefaultLabel);

        activeByDefaultField.setLimit("1,3,2,1"); //$NON-NLS-1$
        activeByDefaultField.setText("" + portal.getActiveByDefault());
        tabSheet.getChildren().add(activeByDefaultField);

        final Label usageOrderLabel = new Label(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.USAGE_ORDER));
        usageOrderLabel.setLimit("0,4"); //$NON-NLS-1$
        tabSheet.getChildren().add(usageOrderLabel);

        usageOrderField.setLimit("1,4,2,1"); //$NON-NLS-1$
        usageOrderField.setText("" + portal.getUsageOrder());
        tabSheet.getChildren().add(usageOrderField);
        
        final Button deleteButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_DELETE));
        deleteButton.setLimit("0,5"); //$NON-NLS-1$
        deleteButton
                .addActionListener(ACTION_CLICK, deletePortalActionListener);
        tabSheet.getChildren().add(deleteButton);

        final Button cancelButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_CANCEL));
        cancelButton.setLimit("1,5"); //$NON-NLS-1$
        cancelButton
                .addActionListener(ACTION_CLICK, cancelPortalActionListener);
        tabSheet.getChildren().add(cancelButton);

        final Button okButton = new Button(getUserSessionDTO()
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_OK));
        okButton.setLimit("2,5"); //$NON-NLS-1$
        okButton.addActionListener(ACTION_CLICK, okPortalActionListener);
        tabSheet.getChildren().add(okButton);
        return tabSheet;
    }

}
