/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.gridboxes;

import java.util.List;

import thinwire.ui.GridBox;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.model.sweden.impl.Vote.Position;
import com.hack23.cia.web.action.user.ParliamentMemberAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class BallotGridBox.
 */
public class BallotGridBox extends GridBox {

    /**
     * Instantiates a new ballot grid box.
     *
     * @param userSessionDTO the user session dto
     * @param ballot the ballot
     * @param votes the votes
     */
    public BallotGridBox(final UserSessionDTO userSessionDTO,final Ballot ballot, final List<Vote> votes) {
        super();

        this.setVisibleHeader(true);
        this.addActionListener(ACTION_CLICK, BeanLocator
                .getApplicationActionListener());

        GridBox.Column nameHeader = new GridBox.Column();
        nameHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.NAME));
        this.getColumns().add(nameHeader);

        GridBox.Column partyHeader = new GridBox.Column();
        partyHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PARTY));
        this.getColumns().add(partyHeader);

        GridBox.Column votePostionHeader = new GridBox.Column();
        votePostionHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.VOTE_POSITION));
        this.getColumns().add(votePostionHeader);

        GridBox.Column winningStatusHeader = new GridBox.Column();
        winningStatusHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WINNING_STATUS));
        this.getColumns().add(winningStatusHeader);

        GridBox.Column partyStatusHeader = new GridBox.Column();
        partyStatusHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PARTY_STATUS));
        this.getColumns().add(partyStatusHeader);

        GridBox.Column winningSideInPartyHeader = new GridBox.Column();
        winningSideInPartyHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WINNING_SIDE_IN_PARTY));
        this.getColumns().add(winningSideInPartyHeader);

        GridBox.Column winningSideHeader = new GridBox.Column();
        winningSideHeader.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WINNING_SIDE));
        this.getColumns().add(winningSideHeader);

        for (Vote vote : votes) {

            String wonOrLost = null;
            String rebelOrLoyal = null;

            if (vote.getPosition().equals(Position.Absent)
                    || vote.getPosition().equals(Position.Neutral)) {
                wonOrLost = "--"; //$NON-NLS-1$
                rebelOrLoyal = "--"; //$NON-NLS-1$
            } else {
                if (vote.isWinning()) {
                    wonOrLost = userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.WON);
                } else {
                    wonOrLost = userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.LOST);
                }

                if (vote.isRebel()) {
                    rebelOrLoyal = userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.PARTY_REBEL);
                } else {
                    rebelOrLoyal = userSessionDTO
                            .getLanguageResource(Agency.LanguageContentKey.PARTY_LOYAL);
                }
            }

            GridBox.Row row = new GridBox.Row(vote.getParliamentMember()
                    .getName(), vote.getParliamentMember().getParty(),
                    userSessionDTO.getLanguageResource(vote.getPosition()), wonOrLost, rebelOrLoyal,
                    userSessionDTO.getLanguageResource(ballot.getPartyBallotResult(
                                    vote.getParliamentMember().getParty())
                            .getWinningPosition()),
                    userSessionDTO.getLanguageResource(ballot.getBallotResult()
                            .getWinningPosition()));
            row.setUserObject(new ParliamentMemberAction(vote
                    .getParliamentMember().getId()));
            this.getRows().add(row);
        }
    }

}
