/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.gridboxes;

import thinwire.ui.GridBox;
import thinwire.ui.GridBox.Column;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;

/**
 * A factory for creating GridBoxColumn objects.
 */
public class GridBoxColumnFactory {

    /**
     * Gets the agrement percentage header.
     *
     * @param userSessionDTO the user session dto
     * @return the agrement percentage header
     */
    protected static Column getAgrementPercentageHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.AGREMENT_PERCENTAGE));
        return header;
    }

    /**
     * Gets the electoral area header.
     *
     * @param userSessionDTO the user session dto
     * @return the electoral area header
     */
    protected static Column getElectoralAreaHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.ELECTORAL_AREA));
        return header;
    }

    /**
     * Gets the first vote header.
     *
     * @param userSessionDTO the user session dto
     * @return the first vote header
     */
    protected static Column getFirstVoteHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.FIRST_VOTE));
        return header;
    }

    /**
     * Gets the key header.
     *
     * @param userSessionDTO the user session dto
     * @return the key header
     */
    public static Column getKeyHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.LANGUAGE_CONTENT_KEY));
        return header;
    }

    /**
     * Gets the last vote header.
     *
     * @param userSessionDTO the user session dto
     * @return the last vote header
     */
    protected static Column getLastVoteHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.LAST_VOTE));
        return header;
    }

    /**
     * Gets the name header.
     *
     * @param userSessionDTO the user session dto
     * @return the name header
     */
    protected static Column getNameHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.NAME));
        return header;
    }

    /**
     * Gets the party header.
     *
     * @param userSessionDTO the user session dto
     * @return the party header
     */
    protected static Column getPartyHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PARTY));
        return header;
    }

    /**
     * Gets the portal matches url header.
     *
     * @param userSessionDTO the user session dto
     * @return the portal matches url header
     */
    protected static Column getPortalMatchesUrlHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.MATCHES_URL));
        return header;
    }

    /**
     * Gets the rank header.
     *
     * @param userSessionDTO the user session dto
     * @return the rank header
     */
    protected static Column getRankHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.RANK));
        return header;
    }

    /**
     * Gets the registered votes header.
     *
     * @param userSessionDTO the user session dto
     * @return the registered votes header
     */
    protected static Column getRegisteredVotesHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.REGISTERED_VOTES));
        return header;
    }

    /**
     * Gets the value header.
     *
     * @param userSessionDTO the user session dto
     * @return the value header
     */
    public static Column getValueHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.LANGUAGE_CONTENT_VALUE));
        return header;
    }

    /**
     * Gets the vote occassions compared header.
     *
     * @param userSessionDTO the user session dto
     * @return the vote occassions compared header
     */
    protected static Column getVoteOccassionsComparedHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.VOTE_OCCASSIONS_COMPARED));
        return header;
    }

    /**
     * Gets the winning occassions header.
     *
     * @param userSessionDTO the user session dto
     * @return the winning occassions header
     */
    protected static Column getWinningOccassionsHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WINNING_OCCASSIONS));
        return header;
    }

    /**
     * Gets the winning percentage header.
     *
     * @param userSessionDTO the user session dto
     * @return the winning percentage header
     */
    protected static Column getWinningPercentageHeader(final UserSessionDTO userSessionDTO) {
        GridBox.Column header = new GridBox.Column();
        header.setName(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WINNING_PERCENTAGE));
        return header;
    }

    /**
     * Instantiates a new grid box column factory.
     */
    protected GridBoxColumnFactory() {
        super();
    }
}
