/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.gridboxes;

import java.util.List;

import thinwire.ui.GridBox;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.web.action.user.ParliamentMemberAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class ParliamentMemberVoteCompareResultGridBox.
 */
public class ParliamentMemberVoteCompareResultGridBox extends GridBox {

    /**
     * Instantiates a new parliament member vote compare result grid box.
     *
     * @param userSessionDTO the user session dto
     * @param enemyList the enemy list
     */
    public ParliamentMemberVoteCompareResultGridBox(final UserSessionDTO userSessionDTO,
            final List<ParliamentMemberVoteCompareResult> enemyList) {
        super();
        this.setVisibleHeader(true);
        this.addActionListener(ACTION_CLICK, BeanLocator
                .getApplicationActionListener());

        this.getColumns().add(GridBoxColumnFactory.getRankHeader(userSessionDTO));
        this.getColumns().add(
                GridBoxColumnFactory.getAgrementPercentageHeader(userSessionDTO));
        this.getColumns().add(
                GridBoxColumnFactory.getVoteOccassionsComparedHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getNameHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getPartyHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getElectoralAreaHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getFirstVoteHeader(userSessionDTO));
        this.getColumns().add(GridBoxColumnFactory.getLastVoteHeader(userSessionDTO));

        int rank = 1;
        for (ParliamentMemberVoteCompareResult parliamentMember : enemyList) {
            GridBox.Row row = new GridBox.Row(rank++, new Float(
                    parliamentMember.getResult()), parliamentMember
                    .getVotesCompared(), parliamentMember
                    .getOpponentParliamentMember().getName(), parliamentMember
                    .getOpponentParliamentMember().getParty(), parliamentMember
                    .getOpponentParliamentMember().getElectoralRegion(),
                    parliamentMember.getOpponentParliamentMember().getParliamentMemberBallotRecord()
                            .getFirstVoteDate(), parliamentMember
                            .getOpponentParliamentMember().getParliamentMemberBallotRecord().getLastVoteDate());
            row.setUserObject(new ParliamentMemberAction(parliamentMember
                    .getOpponentParliamentMember().getId()));
            this.getRows().add(row);
        }
    }

}
