/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.components.panels;

import thinwire.ui.Image;
import thinwire.ui.Label;
import thinwire.ui.Panel;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.web.common.ImageConstants;

/**
 * The Class ErrorMessagePanel.
 */
public class ErrorMessagePanel extends Panel {

    /** The error message. */
    private final Label errorMessage = new Label();
    
    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;

    /**
     * Instantiates a new error message panel.
     *
     * @param userSessionDTO the user session dto
     * @param message the message
     */
    public ErrorMessagePanel(final UserSessionDTO userSessionDTO,final String message) {
        super();
        this.userSessionDTO = userSessionDTO;
        setVisible(false);

        setLayout(new TableLayout(new double[][] { { 0, 0 }, // Column Widths
                { 0 } }, // Row Heights
                2, // Margin around edge of container
                4)); // Spacing between cells

        final Image errorImage = new Image(ImageConstants.ACTION_ERROR);
        errorImage.setSize(ImageConstants.ICON_SIZE, ImageConstants.ICON_SIZE);
        errorImage.setLimit("0,0"); //$NON-NLS-1$
        getChildren().add(errorImage);

        errorMessage.setLimit("1,0"); //$NON-NLS-1$
        getChildren().add(errorMessage);

        errorMessage.setText(" " //$NON-NLS-1$
                + userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.ERROR_MESSAGE) + " : " //$NON-NLS-1$
                + message);
        setVisible(true);
    }
}
