/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.components.panels;

import thinwire.ui.Component;
import thinwire.ui.Panel;
import thinwire.ui.TabFolder;
import thinwire.ui.TabSheet;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;

/**
 * The Class SimpleComponentPanel.
 */
public class SimpleComponentPanel extends Panel {

	/** The tab folder. */
	private final TabFolder tabFolder = new TabFolder();
	
	/** The user session dto. */
	private UserSessionDTO userSessionDTO;
	
    /**
     * Instantiates a new simple component panel.
     *
     * @param title the title
     * @param titleImage the title image
     * @param component the component
     */
    public SimpleComponentPanel(final String title, final String titleImage,
            final Component component) {
        super();

        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        TabSheet componentTabSheet = new TabSheet();
        tabFolder.getChildren().add(componentTabSheet);
        componentTabSheet.setText(title);
        componentTabSheet.setImage(titleImage);
        componentTabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        component.setLimit("0,0"); //$NON-NLS-1$
        componentTabSheet.getChildren().add(component);

        tabFolder.setLimit("0,0,1,1");
        getChildren().add(tabFolder);
    }

    /**
     * Instantiates a new simple component panel.
     *
     * @param title the title
     * @param titleImage the title image
     * @param component the component
     * @param title2 the title2
     * @param titleImage2 the title image2
     * @param component2 the component2
     * @param userSessionDTO the user session dto
     */
    public SimpleComponentPanel(final String title, final String titleImage,
    		final Component component,final String title2, final String titleImage2,
    		final Component component2,final UserSessionDTO userSessionDTO) {
    	this(title,titleImage,component);
		this.userSessionDTO = userSessionDTO;
    	addComponentPanel(title2, titleImage2, component2);
    	 tabFolder.getChildren().add(createTabFolderCitizenOperation(userSessionDTO));
    }

    
	/**
	 * Adds the component panel.
	 *
	 * @param title the title
	 * @param titleImage the title image
	 * @param component the component
	 */
    public final void addComponentPanel(final String title, final String titleImage,
            final Component component) {

        TabSheet componentTabSheet = new TabSheet();
        tabFolder.getChildren().add(componentTabSheet);
        componentTabSheet.setText(title);
        componentTabSheet.setImage(titleImage);
        componentTabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        component.setLimit("0,0"); //$NON-NLS-1$
        componentTabSheet.getChildren().add(component);        
    }    
    
    /**
     * Creates the tab folder citizen operation.
     *
     * @param userSessionDTO the user session dto
     * @return the tab sheet
     */
    private TabSheet createTabFolderCitizenOperation(final UserSessionDTO userSessionDTO) {
    	  this.userSessionDTO = userSessionDTO;
		TabSheet tabSheet = new TabSheet();

          tabSheet.setText(userSessionDTO
                  .getLanguageResource(Agency.LanguageContentKey.CITIZEN_OPERATION));
          tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                  // Widths
                  { 0 } }, // Row Heights
                  1, // Margin around edge of container
                  5)); // Spacing between cells

          TabFolder tabFolder = new TabFolder();
          tabFolder.setLimit("0,0"); //$NON-NLS-1$

          tabFolder.getChildren().add(
                  createTabFolderGrading());
          tabFolder.getChildren().add(
                  createTabFolderForum());
          tabFolder.getChildren().add(
                  createTabFolderOpinions());
          tabFolder.getChildren().add(
                  createTabFolderShortComment());
          tabFolder.getChildren().add(
                  createTabFolderVote());
          
          tabFolder.setCurrentIndex(0);
          tabSheet.getChildren().add(tabFolder);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder forum.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderForum() {     
		TabSheet tabSheet = new TabSheet();

	        tabSheet.setText(userSessionDTO
	                .getLanguageResource(Agency.LanguageContentKey.FORUM));
	        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
	                // Widths
	                { 0 } }, // Row Heights
	                1, // Margin around edge of container
	                5)); // Spacing between cells
	        
	        return tabSheet;
	}


	/**
	 * Creates the tab folder grading.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderGrading() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.GRADING));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder opinions.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderOpinions() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.OPINIONS));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder short comment.
	 *
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderShortComment() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SHORT_COMMENT));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

    /**
     * Creates the tab folder vote.
     *
     * @return the tab sheet
     */
    private TabSheet createTabFolderVote() {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.VOTE));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        
        return tabSheet;
	}

    
    
}
