/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.user;

import thinwire.ui.TabFolder;
import thinwire.ui.TabSheet;
import thinwire.ui.WebBrowser;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.ParliamentChart;
import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.web.common.ImageConstants;
import com.hack23.cia.web.views.components.gridboxes.BallotGridBox;
import com.hack23.cia.web.views.components.panels.ImagePanel;

/**
 * The Class BallotPanel.
 */
public class BallotPanel extends AbstractParliamentOperationPanel {

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;

	/**
	 * Instantiates a new ballot panel.
	 *
	 * @param userSessionDTO the user session dto
	 * @param ballot the ballot
	 */
    public BallotPanel(final UserSessionDTO userSessionDTO, final Ballot ballot) {        
		super(userSessionDTO);
    	this.userSessionDTO = userSessionDTO;
        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        final TabFolder tabFolder = createTabFolder(ballot);
        
        tabFolder.getChildren().add(
                createTabFolderCharts(ballot));
        
        tabFolder.getChildren().add(
                createTabFolderCitizenOperation());
        tabFolder.setLimit("0,0,1,1"); //$NON-NLS-1$
        getChildren().add(tabFolder);
    }

    /**
     * Creates the tab ballot.
     *
     * @param ballot the ballot
     * @return the tab sheet
     */
    private TabSheet createTabBallot(final Ballot ballot) {
        TabSheet homePage = new TabSheet();

        homePage.setText(ballot.getDescription());
        homePage.setImage(ImageConstants.BALLOT_IMAGE_SMALL);

        homePage.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        
        final BallotGridBox ballotGridBox = new BallotGridBox(userSessionDTO,ballot, ballot.getVotes());
        ballotGridBox.setLimit("0,0"); //$NON-NLS-1$
        homePage.getChildren().add(ballotGridBox);
        return homePage;
    }

	/**
	 * Creates the tab folder.
	 *
	 * @param ballot the ballot
	 * @return the tab folder
	 */
    private TabFolder createTabFolder(final Ballot ballot) {
        final TabFolder tabFolder = new TabFolder();
        tabFolder.getChildren().add(createTabBallot(ballot));
        
        if (ballot.getVoteResultsHref() != null) {
            TabSheet homePageTab = createTabHomePage(ballot);
            tabFolder.getChildren().add(homePageTab);
        }
        return tabFolder;
    }
	
	/**
	 * Creates the tab folder chart outcome.
	 *
	 * @param ballot the ballot
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartOutcome(
			final Ballot ballot) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.OUTCOME));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Outcome, ballot, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder chart political party behavior.
	 *
	 * @param ballot the ballot
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartPoliticalPartyBehavior(
			final Ballot ballot) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.POLITICAL_PARTY_BEHAVIOR));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.PoliticalPartyBehavior, ballot, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder chart proffessional behavior.
	 *
	 * @param ballot the ballot
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartProffessionalBehavior(final Ballot ballot) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PROFFESSIONAL_BEHAVIOR));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.ProffessionalBehavior, ballot, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}


	/**
	 * Creates the tab folder charts.
	 *
	 * @param ballot the ballot
	 * @return the tab sheet
	 */
    private TabSheet createTabFolderCharts(final Ballot ballot) {
     	  TabSheet tabSheet = new TabSheet();

          tabSheet.setText(userSessionDTO
                  .getLanguageResource(Agency.LanguageContentKey.CHARTS));
          tabSheet.setImage(ImageConstants.CHART_IMAGE_SMALL);
          tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                  // Widths
                  { 0 } }, // Row Heights
                  1, // Margin around edge of container
                  5)); // Spacing between cells

          TabFolder tabFolder = new TabFolder();
          tabFolder.setLimit("0,0"); //$NON-NLS-1$

          tabFolder.getChildren().add(
                  createTabFolderChartSummary(ballot));
          tabFolder.getChildren().add(
                  createTabFolderChartOutcome(ballot));
          tabFolder.getChildren().add(
                  createTabFolderChartPoliticalPartyBehavior(ballot));
          tabFolder.getChildren().add(
                  createTabFolderChartProffessionalBehavior(ballot));
          
          tabFolder.setCurrentIndex(0);
          tabSheet.getChildren().add(tabFolder);
          return tabSheet;
	}

    
    /**
     * Creates the tab folder chart summary.
     *
     * @param ballot the ballot
     * @return the tab sheet
     */
	private TabSheet createTabFolderChartSummary(
			final Ballot ballot) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SUMMARY));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Summary, ballot, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}
    
    /**
     * Creates the tab home page.
     *
     * @param ballot the ballot
     * @return the tab sheet
     */
    private TabSheet createTabHomePage(final Ballot ballot) {
        TabSheet homePage = new TabSheet();

        homePage.setText(ballot.getDescription());

        homePage.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        final WebBrowser comp = new WebBrowser();
        comp.setLimit("0,0"); //$NON-NLS-1$
        comp.setLocation(ballot.getVoteResultsHref());
        homePage.getChildren().add(comp);
        return homePage;
    }

    
}
