/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.user;

import org.springframework.security.authentication.encoding.Md5PasswordEncoder;
import org.springframework.security.authentication.encoding.PasswordEncoder;

import thinwire.ui.Button;
import thinwire.ui.Label;
import thinwire.ui.Panel;
import thinwire.ui.TextField;
import thinwire.ui.AlignTextComponent.AlignX;
import thinwire.ui.event.ActionEvent;
import thinwire.ui.event.ActionListener;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.user.UserAccountActionEvent;
import com.hack23.cia.web.action.user.UserAccountAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class LoginPanel.
 */
public class LoginPanel extends Panel {

    /** The login action listener. */
    private final ActionListener loginActionListener = new ActionListener() {
        public void actionPerformed(final ActionEvent ev) {
            Button okButton = (Button) ev.getSource();
            okButton.setUserObject(new UserAccountAction(UserAccountActionEvent.Operation.Process_login, nameField.getText(), passwordEncoder.encodePassword(passwordField.getText(), null)));           
            BeanLocator.getApplicationActionListener().actionPerformed(ev);
        }
    };

    /** The name field. */
    private final TextField nameField = new TextField();

    /** The password encoder. */
    private final PasswordEncoder passwordEncoder = new Md5PasswordEncoder();

    /** The password field. */
    private final TextField passwordField = new TextField();

    /**
     * Instantiates a new login panel.
     *
     * @param userSessionDTO the user session dto
     */
    public LoginPanel(final UserSessionDTO userSessionDTO) {
        super();
        setLayout(new TableLayout(new double[][] { { 0, 0 }, // Column
                // Widths
                { 0, 0, 0, 0 } }, // Row Heights
                10, // Margin around edge of container
                5));
        final Label nameLabel = new Label(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.NAME));
        nameLabel.setLimit("0,0"); //$NON-NLS-1$
        getChildren().add(nameLabel);

        nameField.setLimit("1,0"); //$NON-NLS-1$
        getChildren().add(nameField);

        final Label passwordLabel = new Label(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PASSWORD));
        passwordLabel.setLimit("0,1"); //$NON-NLS-1$
        passwordLabel.setAlignX(AlignX.LEFT);
        getChildren().add(passwordLabel);

        passwordField.setLimit("1,1"); //$NON-NLS-1$
        passwordField.setInputHidden(true);
        getChildren().add(passwordField);

        final Button okButton = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.BUTTON_OK));
        okButton.setLimit("1,3"); //$NON-NLS-1$
        okButton.addActionListener(ACTION_CLICK, loginActionListener);
        getChildren().add(okButton);
    }
}
