/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.user;

import java.util.List;

import thinwire.ui.GridBox;
import thinwire.ui.TabFolder;
import thinwire.ui.TabSheet;
import thinwire.ui.WebBrowser;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.ParliamentChart;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.ParliamentMemberVoteCompareResult;
import com.hack23.cia.model.sweden.impl.RegisterInformation;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.web.common.ImageConstants;
import com.hack23.cia.web.views.components.gridboxes.ParliamentMemberVoteCompareResultGridBox;
import com.hack23.cia.web.views.components.gridboxes.RegisterInformationGridbox;
import com.hack23.cia.web.views.components.gridboxes.VoteGridBox;
import com.hack23.cia.web.views.components.panels.ImagePanel;

/**
 * The Class ParliamentMemberSummaryPanel.
 */
public class ParliamentMemberSummaryPanel extends AbstractParliamentOperationPanel {

    /** The user session dto. */
    private final UserSessionDTO userSessionDTO;
    
    
    /**
     * Instantiates a new parliament member summary panel.
     *
     * @param userSessionDTO the user session dto
     * @param parliamentMember the parliament member
     * @param votes the votes
     * @param friendList the friend list
     * @param enemyList the enemy list
     * @param partyFriendList the party friend list
     * @param partyEnemyList the party enemy list
     * @param registerInformation the register information
     */
    public ParliamentMemberSummaryPanel(final UserSessionDTO userSessionDTO,
            final ParliamentMember parliamentMember, final List<Vote> votes,
            final List<ParliamentMemberVoteCompareResult> friendList,
            final List<ParliamentMemberVoteCompareResult> enemyList,
            final List<ParliamentMemberVoteCompareResult> partyFriendList,
            final List<ParliamentMemberVoteCompareResult> partyEnemyList,
            final RegisterInformation registerInformation) {
        super(userSessionDTO);
        this.userSessionDTO = userSessionDTO;
        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        final TabFolder tabFolder = new TabFolder();
        tabFolder.setLimit("0,0,1,1"); //$NON-NLS-1$

        tabFolder.getChildren().add(
                createInformationTabSheet(userSessionDTO.getUserSession(), parliamentMember,
                        registerInformation, votes));
        tabFolder.getChildren().add(
                createTabFolderCharts(parliamentMember));
        tabFolder.getChildren().add(
                createTabFolderFriendsAndEnemies(friendList, enemyList,
                        partyFriendList, partyEnemyList));
        tabFolder.getChildren().add(
                createTabFolderCitizenOperation());
     
        tabFolder.setCurrentIndex(0);
        getChildren().add(tabFolder);

    }

    /**
     * Creates the information tab sheet.
     *
     * @param userSession the user session
     * @param parliamentMember the parliament member
     * @param registerInformation the register information
     * @param votes the votes
     * @return the tab sheet
     */
    private TabSheet createInformationTabSheet(final UserSession userSession,
            final ParliamentMember parliamentMember,
            final RegisterInformation registerInformation,
            final List<Vote> votes) {
        TabSheet informationTabSheet = new TabSheet();

        informationTabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.INFORMATION) + ":" + parliamentMember.getName());
        informationTabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        TabFolder tabFolder = new TabFolder();
        tabFolder.setLimit("0,0"); //$NON-NLS-1$

        if (parliamentMember.getHref() != null) {
            TabSheet homePageTab = createTabHomePage(userSession,
                    parliamentMember);
            tabFolder.getChildren().add(homePageTab);
        }

        if (parliamentMember.getWikiHref() != null) {
            TabSheet wikiPageTab = createTabWikiPage(parliamentMember,
                    userSession);
            tabFolder.getChildren().add(wikiPageTab);
        }

        TabSheet otherLoyaltiesTab = createTabSheetOtherLoyalties(registerInformation);
        tabFolder.getChildren().add(otherLoyaltiesTab);

        TabSheet votesTabSheet = createVoteTabSheet(votes);
        tabFolder.getChildren().add(votesTabSheet);

        tabFolder.setCurrentIndex(0);
        informationTabSheet.getChildren().add(tabFolder);
        return informationTabSheet;
    }


	/**
	 * Creates the tab folder chart outcome.
	 *
	 * @param parliamentMember the parliament member
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartOutcome(
			final ParliamentMember parliamentMember) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.OUTCOME));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Outcome, parliamentMember, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder chart political party behavior.
	 *
	 * @param parliamentMember the parliament member
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartPoliticalPartyBehavior(
			final ParliamentMember parliamentMember) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.POLITICAL_PARTY_BEHAVIOR));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.PoliticalPartyBehavior, parliamentMember, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder chart proffessional behavior.
	 *
	 * @param parliamentMember the parliament member
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartProffessionalBehavior(final
			ParliamentMember parliamentMember) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PROFFESSIONAL_BEHAVIOR));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.ProffessionalBehavior, parliamentMember, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

	/**
	 * Creates the tab folder charts.
	 *
	 * @param parliamentMember the parliament member
	 * @return the tab sheet
	 */
    private TabSheet createTabFolderCharts(final ParliamentMember parliamentMember) {
    	  TabSheet tabSheet = new TabSheet();

          tabSheet.setText(userSessionDTO
                  .getLanguageResource(Agency.LanguageContentKey.CHARTS));
          tabSheet.setImage(ImageConstants.CHART_IMAGE_SMALL);
          tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                  // Widths
                  { 0 } }, // Row Heights
                  1, // Margin around edge of container
                  5)); // Spacing between cells

          TabFolder tabFolder = new TabFolder();
          tabFolder.setLimit("0,0"); //$NON-NLS-1$

          tabFolder.getChildren().add(
                  createTabFolderChartSummary(parliamentMember));
          tabFolder.getChildren().add(
                  createTabFolderChartOutcome(parliamentMember));
          tabFolder.getChildren().add(
                  createTabFolderChartPoliticalPartyBehavior(parliamentMember));
          tabFolder.getChildren().add(
                  createTabFolderChartProffessionalBehavior(parliamentMember));
          
          tabFolder.setCurrentIndex(0);
          tabSheet.getChildren().add(tabFolder);
          return tabSheet;
   }

	/**
	 * Creates the tab folder chart summary.
	 *
	 * @param parliamentMember the parliament member
	 * @return the tab sheet
	 */
	private TabSheet createTabFolderChartSummary(
			final ParliamentMember parliamentMember) {
		TabSheet tabSheet = new TabSheet();

        tabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SUMMARY));
        tabSheet.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells
        ImagePanel imagePanel = new ImagePanel(ParliamentChart.getFileName(ParliamentChart.Summary, parliamentMember, userSessionDTO.getUserSession().getLanguage()));
        imagePanel.setLimit("0,0");
        tabSheet.getChildren().add(imagePanel);
        
        return tabSheet;
	}

 

	/**
	 * Creates the tab folder friends and enemies.
	 *
	 * @param friendList the friend list
	 * @param enemyList the enemy list
	 * @param partyFriendList the party friend list
	 * @param partyEnemyList the party enemy list
	 * @return the tab sheet
	 */
    private TabSheet createTabFolderFriendsAndEnemies(
            final List<ParliamentMemberVoteCompareResult> friendList,
            final List<ParliamentMemberVoteCompareResult> enemyList,
            final List<ParliamentMemberVoteCompareResult> partyFriendList,
            final List<ParliamentMemberVoteCompareResult> partyEnemyList) {

        TabSheet friendsAndEnemiesTabSheet = new TabSheet();

        friendsAndEnemiesTabSheet.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.FRIENDS_AND_ENEMIES));
        friendsAndEnemiesTabSheet.setLayout(new TableLayout(new double[][] {
                { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        TabFolder tabFolder = new TabFolder();

        TabSheet friendsTab = createTabSheetRelations(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.TOP_BEST_FRIENDS), friendList);
        tabFolder.getChildren().add(friendsTab);

        TabSheet enenmyTab = createTabSheetRelations(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.TOP_WORST_ENEMIES), enemyList);
        tabFolder.getChildren().add(enenmyTab);

        TabSheet friendsPartyTab = createTabSheetRelations(
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.TOP_BEST_FRIENDS)
                        + " " + userSessionDTO //$NON-NLS-1$
                                .getLanguageResource(Agency.LanguageContentKey.INSIDE_PARTY),
                partyFriendList);
        tabFolder.getChildren().add(friendsPartyTab);

        TabSheet enenmyPartyTab = createTabSheetRelations(
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.TOP_WORST_ENEMIES)
                        + " " + userSessionDTO //$NON-NLS-1$
                                .getLanguageResource(Agency.LanguageContentKey.INSIDE_PARTY),
                partyEnemyList);
        tabFolder.getChildren().add(enenmyPartyTab);

        friendsAndEnemiesTabSheet.getChildren().add(tabFolder);

        return friendsAndEnemiesTabSheet;
    }


    /**
     * Creates the tab home page.
     *
     * @param userSession the user session
     * @param parliamentMember the parliament member
     * @return the tab sheet
     */
    private TabSheet createTabHomePage(final UserSession userSession,
            final ParliamentMember parliamentMember) {
        TabSheet homePage = new TabSheet();

        homePage.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.RIKSDAG_INFORMATION));
        homePage.setImage(ImageConstants.POLITICAL_PARTY_ICON_SMALL);

        homePage.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        WebBrowser comp = new WebBrowser();
        comp.setLimit("0,0"); //$NON-NLS-1$

        if (Language.SWEDISH_LANGUAGE_CODE.equalsIgnoreCase(userSession
                .getLanguage().getShortCode())) {
            comp.setLocation(parliamentMember.getHref());
        } else {
            comp.setLocation(parliamentMember.getInternationalHref());
        }
        homePage.getChildren().add(comp);
        return homePage;
    }

    /**
     * Creates the tab sheet other loyalties.
     *
     * @param registerInformation the register information
     * @return the tab sheet
     */
    private TabSheet createTabSheetOtherLoyalties(
            final RegisterInformation registerInformation) {
        TabSheet votesTabShett = new TabSheet();

        votesTabShett.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.OTHER_LOYALTIES));

        votesTabShett.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        GridBox registerInformationBox = new RegisterInformationGridbox(userSessionDTO,
                registerInformation);
        registerInformationBox.setLimit("0,0"); //$NON-NLS-1$
        votesTabShett.getChildren().add(registerInformationBox);

        return votesTabShett;
    }

    /**
     * Creates the tab sheet relations.
     *
     * @param title the title
     * @param enemyList the enemy list
     * @return the tab sheet
     */
    private TabSheet createTabSheetRelations(final String title,
            final List<ParliamentMemberVoteCompareResult> enemyList) {
        TabSheet members = new TabSheet();

        members.setText(title);
        members.setImage(ImageConstants.POLITICAL_PARTY_ICON_SMALL);

        members.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        GridBox orgBox = new ParliamentMemberVoteCompareResultGridBox(userSessionDTO,enemyList);
        orgBox.setLimit("0,0"); //$NON-NLS-1$
        members.getChildren().add(orgBox);

        return members;
    }

    /**
     * Creates the tab wiki page.
     *
     * @param parliamentMember the parliament member
     * @param userSession the user session
     * @return the tab sheet
     */
    private TabSheet createTabWikiPage(final ParliamentMember parliamentMember,
            final UserSession userSession) {
        TabSheet wikiPage = new TabSheet();

        wikiPage.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WIKI));
        wikiPage.setImage(ImageConstants.POLITICAL_PARTY_ICON_SMALL);

        wikiPage.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        WebBrowser comp = new WebBrowser();
        comp.setLimit("0,0"); //$NON-NLS-1$

        if (Language.SWEDISH_LANGUAGE_CODE.equalsIgnoreCase(userSession
                .getLanguage().getShortCode())) {
            comp.setLocation(parliamentMember.getWikiHref());
        } else {
            comp.setLocation(parliamentMember.getEnglishWikiHref());
        }
        wikiPage.getChildren().add(comp);
        return wikiPage;
    }

    /**
     * Creates the vote tab sheet.
     *
     * @param votes the votes
     * @return the tab sheet
     */
    private TabSheet createVoteTabSheet(final List<Vote> votes) {
        TabSheet votesTabShett = new TabSheet();

        votesTabShett.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.VOTES));

        votesTabShett.setLayout(new TableLayout(new double[][] { { 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        GridBox votesBox = new VoteGridBox(userSessionDTO,votes);
        votesBox.setLimit("0,0"); //$NON-NLS-1$
        votesTabShett.getChildren().add(votesBox);

        return votesTabShett;
    }

}
