/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.user;

import thinwire.ui.Button;
import thinwire.ui.Component;
import thinwire.ui.Image;
import thinwire.ui.Label;
import thinwire.ui.Panel;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.user.ExternalUrlActionEvent;
import com.hack23.cia.web.action.user.ExternalUrlAction;
import com.hack23.cia.web.common.BeanLocator;
import com.hack23.cia.web.common.ImageConstants;

/**
 * The Class PositionBarPanel.
 */
public class PositionBarPanel extends Panel {

    /** The current action. */
    private final Label currentAction = new Label();

    /** The current page title. */
    private String currentPageTitle;

    /** The current user object. */
    private Object currentUserObject = null;

    /** The last action button. */
    private final Button lastActionButton = new Button();

    /**
     * Instantiates a new position bar panel.
     *
     * @param userSessionDTO the user session dto
     */
    public PositionBarPanel(final UserSessionDTO userSessionDTO) {
        super();
        setLayout(new TableLayout(new double[][] { { 0, 0, 0, 0, 0, 0, 0, 0 }, // Column
                // Widths
                { 0 } }, // Row Heights
                2, // Margin around edge of container
                5)); // Spacing between cells

        final Image openSourceLogo = new Image(ImageConstants.OPEN_SOURCE_LOGO);
        openSourceLogo.setLimit("0,0,0,0");
        openSourceLogo.setSize(42, 36);

        final Label currentActionLabel = new Label(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.CURRENT_ACTION));
        currentActionLabel.setWrapText(true);
        currentActionLabel.setLimit("1,0,1,1"); //$NON-NLS-1$

        currentAction.setWrapText(true);
        currentAction.setLimit("2,0,2,1"); //$NON-NLS-1$

        Button projectInformation = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.PROJECT_INFORMATION));
        projectInformation.addActionListener(Component.ACTION_CLICK,
                BeanLocator.getApplicationActionListener());
        projectInformation.setUserObject(new ExternalUrlAction(
                ExternalUrlActionEvent.Operation.ShowProjectInformation));
        projectInformation.setLimit("4,0,1,1"); //$NON-NLS-1$

        Button projectDonate = new Button();        
        projectDonate.setImage("http://images.sourceforge.net/images/project-support.jpg");
        projectDonate.addActionListener(Component.ACTION_CLICK, BeanLocator
                .getApplicationActionListener());
        projectDonate.setUserObject(new ExternalUrlAction(
                ExternalUrlActionEvent.Operation.ShowDonateToProject));
        projectDonate.setLimit("5,0,1,1"); //$NON-NLS-1$

        Button wikiLeaks = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.WIKILEAKS));
        wikiLeaks.addActionListener(Component.ACTION_CLICK, BeanLocator
                .getApplicationActionListener());
        wikiLeaks.setUserObject(new ExternalUrlAction(
                ExternalUrlActionEvent.Operation.ShowWikiLeaks));
        wikiLeaks.setLimit("6,0,1,1"); //$NON-NLS-1$

        lastActionButton.setLimit("7,0,1,1"); //$NON-NLS-1$       
        lastActionButton.setImage(ImageConstants.GO_PREVIOUS_ICON);
        lastActionButton.addActionListener(Component.ACTION_CLICK, BeanLocator
                .getApplicationActionListener());

        getChildren().add(openSourceLogo);
        getChildren().add(currentActionLabel);
        getChildren().add(currentAction);
        getChildren().add(projectInformation);
        getChildren().add(wikiLeaks);
        getChildren().add(projectDonate);
        getChildren().add(lastActionButton);

    }

    /**
     * Gets the current action.
     *
     * @return the current action
     */
    public final Label getCurrentAction() {
        return currentAction;
    }

    /**
     * Gets the current page title.
     *
     * @return the current page title
     */
    public final String getCurrentPageTitle() {
        return currentPageTitle;
    }

    /**
     * Gets the current user object.
     *
     * @return the current user object
     */
    public final Object getCurrentUserObject() {
        return currentUserObject;
    }

    /**
     * Gets the last action button.
     *
     * @return the last action button
     */
    public final Button getLastActionButton() {
        return lastActionButton;
    }

    /**
     * Sets the current page title.
     *
     * @param pageTitle the new current page title
     */
    public final void setCurrentPageTitle(final String pageTitle) {
        currentPageTitle = pageTitle;
    }

    /**
     * Sets the current user object.
     *
     * @param currentUserObject the new current user object
     */
    public final void setCurrentUserObject(final Object currentUserObject) {
        this.currentUserObject = currentUserObject;
    }
}
