/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/
package com.hack23.cia.web.views.user;

import thinwire.ui.Button;
import thinwire.ui.Component;
import thinwire.ui.Label;
import thinwire.ui.Panel;
import thinwire.ui.TextField;
import thinwire.ui.event.ActionEvent;
import thinwire.ui.event.ActionListener;
import thinwire.ui.event.KeyPressEvent;
import thinwire.ui.event.KeyPressListener;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.web.action.common.ControllerActionListener;
import com.hack23.cia.web.action.user.SearchAction;
import com.hack23.cia.web.common.BeanLocator;

/**
 * The Class SearchPanel.
 */
public class SearchPanel extends Panel {

    /** The application action listener. */
    private final ControllerActionListener applicationActionListener;

    /** The search text field. */
    private final TextField searchTextField = new TextField();

    /**
     * Instantiates a new search panel.
     *
     * @param userSessionDTO the user session dto
     */
    public SearchPanel(final UserSessionDTO userSessionDTO) {
        super();
        applicationActionListener = (ControllerActionListener) BeanLocator
                .getApplicationActionListener();

        setLayout(new TableLayout(new double[][] { { 0 }, // Column Widths
                { 0, 0, 0 } }, // Row Heights
                1, // Margin around edge of container
                5)); // Spacing between cells

        final Label searchDescription = new Label(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SEARCH_DESCRIPTION));
        searchDescription.setWrapText(true);
        searchDescription.setLimit("0,0,1,1"); //$NON-NLS-1$

        searchTextField.setLimit("0,1,1,1"); //$NON-NLS-1$

        final Button actionButton = new Button(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SEARCH));
        actionButton.setLimit("0,2,1,1"); //$NON-NLS-1$
        actionButton.addActionListener(Component.ACTION_CLICK,
                new ActionListener() {

                    @Override
                    public void actionPerformed(final ActionEvent ev) {
                        Object source = ev.getSource();

                        String searchString = searchTextField.getText();
                        searchTextField.setText(""); //$NON-NLS-1$

                        ((Component) source).setUserObject(new SearchAction(
                                searchString));
                        applicationActionListener.actionPerformed(ev);

                    }
                });
        searchTextField.addKeyPressListener("Enter", new KeyPressListener() { //$NON-NLS-1$

                    @Override
                    public void keyPress(final KeyPressEvent ev) {
                        Object source = ev.getSource();

                        String searchString = searchTextField.getText();
                        searchTextField.setText(""); //$NON-NLS-1$

                        ((Component) source).setUserObject(new SearchAction(
                                searchString));
                        applicationActionListener.keyPress(ev);
                    }
                });

        getChildren().add(searchDescription);
        getChildren().add(actionButton);
        getChildren().add(searchTextField);
    }

}
