/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.web.views.user;

import thinwire.ui.Label;
import thinwire.ui.Panel;
import thinwire.ui.layout.TableLayout;

import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.user.AbstractTopListActionEvent;
import com.hack23.cia.web.action.user.TopListAction;
import com.hack23.cia.web.common.ImageConstants;
import com.hack23.cia.web.views.components.panels.CategoryDescriptionPanel;

/**
 * The Class WelcomePanel.
 */
public class WelcomePanel extends Panel {

    /**
     * Instantiates a new welcome panel.
     *
     * @param userSessionDTO the user session dto
     */
    public WelcomePanel(final UserSessionDTO userSessionDTO) {
        super();
        setLayout(new TableLayout(new double[][] { { 0, 0, 0 }, // Column Widths
                { 0, 0, 0 } }, // Row Heights
                10, // Margin around edge of container
                5)); // Spacing between cells
        // Image

        Label labelSiteDescription = new Label();
        labelSiteDescription.setLimit("0,0,3,1"); //$NON-NLS-1$
        labelSiteDescription.setWrapText(true);
        labelSiteDescription.setText(userSessionDTO
                .getLanguageResource(Agency.LanguageContentKey.SITE_DESCRIPTION));

        CategoryDescriptionPanel winnerPanel = new CategoryDescriptionPanel(
                ImageConstants.WINNER_ICON,
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_WINNERS),
                new TopListAction(
                        AbstractTopListActionEvent.Operation.TopWinners),
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_WINNERS_DESCRIPTION));
        winnerPanel.setLimit("0, 1, 1, 1"); //$NON-NLS-1$

        CategoryDescriptionPanel loserPanel = new CategoryDescriptionPanel(
                ImageConstants.LOSER_ICON,
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_LOSERS),
                new TopListAction(
                        AbstractTopListActionEvent.Operation.TopLosers),
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_LOSERS_DESCRIPTION));
        loserPanel.setLimit("0, 2, 1, 1"); //$NON-NLS-1$

        CategoryDescriptionPanel loyalPanel = new CategoryDescriptionPanel(
                ImageConstants.LOYAL_ICON,
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_LOYAL),
                new TopListAction(
                        AbstractTopListActionEvent.Operation.TopLoyals),
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_LOYAL_DESCRIPTION));
        loyalPanel.setLimit("1, 1, 1, 1"); //$NON-NLS-1$

        CategoryDescriptionPanel rebelPanel = new CategoryDescriptionPanel(
                ImageConstants.REBEL_ICON,
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_REBELS),
                new TopListAction(
                        AbstractTopListActionEvent.Operation.TopRebels),
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_REBELS_DESCRIPTION));
        rebelPanel.setLimit("1, 2, 1, 1"); //$NON-NLS-1$

        CategoryDescriptionPanel presencePanel = new CategoryDescriptionPanel(
                ImageConstants.PRESENCE_ICON,
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_PRESENCE),
                new TopListAction(
                        AbstractTopListActionEvent.Operation.TopPresent),
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_PRESENCE_DESCRIPTION));
        presencePanel.setLimit("2, 1, 1, 1"); //$NON-NLS-1$

        CategoryDescriptionPanel absencePanel = new CategoryDescriptionPanel(
                ImageConstants.ABSENCE_ICON,
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_ABSENCE),
                new TopListAction(
                        AbstractTopListActionEvent.Operation.TopAbsent),
                userSessionDTO
                        .getLanguageResource(Agency.LanguageContentKey.PARLIAMENT_MEMBERS_ABSENCE_DESCRIPTION));
        absencePanel.setLimit("2, 2, 1, 1"); //$NON-NLS-1$       

        getChildren().add(labelSiteDescription);
        getChildren().add(winnerPanel);
        getChildren().add(loserPanel);
        getChildren().add(loyalPanel);
        getChildren().add(rebelPanel);
        getChildren().add(presencePanel);
        getChildren().add(absencePanel);
    }
}
